#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: useradmin.cgi, apply_applicationform.cgi              ||
# || Administrate user accounts                                           ||
# || (c) 2001 - 2005 Christian Kuelker                                    ||
# || License: GPL version 2 or later                                      ||
# +========================================================================+

package useradmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Conversion;
use CipUX::Cat;
use CipUX::Task;

my $BRAND   = "cipworx";
my $PROJECT = "cipux";

my $cgi_name = $0;
# /usr/share/webmin/cat/useradmin.cgi
# /usr/share/webmin/cat/apply_applicationform.cgi
$cgi_name =~ s%^.+/%%; # -> apply_applicationform.cgi
my $SCRIPT = $cgi_name;

my $quotatype       = 0; # userquota
my $reread_userlist = 0; # to be reread if new user
my $dialog          = 0;
my @skel = ();   # to save some default skels
my @course = (); # to save some default courses

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"- ReadParse...");
ReadParse();# webmin

$size = 0;
my $letter    = $in{'letter'} if defined($in{'letter'});
my $action    = $in{'action'} if defined($in{'action'});# action
my $user      = $in{'user'}   if defined($in{'user'});# action
my $urole     = $in{'urole'}  if defined($in{'urole'});# action
my $crole     = $in{'crole'}  if defined($in{'crole'});# action
my $skel      = $in{'skel'}   if defined($in{'skel'});# skel

my $uidNumber = $in{'uidNumber'} if defined($in{'uidNumber'});# action = set
$size         = int($in{'size'}) if defined($in{'size'});# quotasize

# TOTO: force $size to be a reasonable value
$size = 0 if $size < 0;
&log($SCRIPT,"- \$size = [$size]");

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

# =========================================================================+
# ||               WARNING delete user (question)                         ||
# =========================================================================+
if($user ne "" and defined($in{useradmin_delete_user})){
  $dialog=1;
  &log($SCRIPT,"- useradmin_delete_user [$user] ");

  # realy want to delte this user?
  &cat_warn_dialog($SCRIPT,
		   &text('useradmin_delete'),
		   &text('useradmin_delete_question',$user),
		   $user,$crole,'useradmin_delete_user_ok',
		   &text('chancel'),$letter);
}

# =========================================================================+
# ||                Delete user (execution)                               ||
# =========================================================================+
if($user ne "" and defined($in{useradmin_delete_user_ok})){
  &log($SCRIPT,"@ useradmin_delete_user, user $user");
  print "<ul><li>".&text('delete_group',$user)."</li>";
  &cipux_task_delete_user('cgi',$user);
  print "</ul>";
}

# =========================================================================+
# ||                Change user data                                      ||
# =========================================================================+
if($user ne "" and $action eq "data"){
  print "Not implemented yet!<br>";
}

# =========================================================================+
# ||               WARNING Reset Home Dir (Question)                      ||
# =========================================================================+
if($user ne "" and defined($in{useradmin_reset_homedir})){
  $dialog=1;
  &log($SCRIPT,"- useradmin_reset_homedir");
  &cat_warn_dialog($SCRIPT,
		   &text('useradmin_reset'),
		   &text('useradmin_reset_question',$user),
		   $user,$crole,'useradmin_reset_homedir_ok',
		   &text('chancel'),$letter);
}

# =========================================================================+
# ||               WARNING Restore Home Dir (Question)                    ||
# =========================================================================+
if($user ne "" and defined($in{useradmin_restore_homedir})){
  $dialog=1;
  &log($SCRIPT,"- useradmin_restore_homedir");
  &cat_warn_dialog($SCRIPT,
		   &text('useradmin_restore'),
		   &text('useradmin_restore_question',$user),
		   $user,$crole,'useradmin_restore_homedir_ok',
		   &text('chancel'),$letter);
}

# =========================================================================+
# ||               Reset or Restore Home Dir                              ||
# =========================================================================+
&log($SCRIPT,"- reset or restore homedir: [$user][$in{urole}][$in{crole}][$in{useradmin_reset_homedir_ok}][$in{useradmin_restore_homedir_ok}]");
if($user ne "" and defined($in{crole})){
  if( defined($in{useradmin_reset_homedir_ok})
      or defined($in{useradmin_restore_homedir_ok})
    ){

    #MODE=1 restore, MODE=2 reset
    my $mode = "";
    $mode = "restore" if defined($in{useradmin_restore_homedir_ok});
    $mode = "reset"   if defined($in{useradmin_reset_homedir_ok});
    my $text = '';
    $text = &text('useradmin_restore') if $mode eq 'restore';
    $text = &text('useradmin_reset')   if $mode eq 'reset';
    print "<ul><li>$text ".&text('useradmin_login',$user)."</li>";

    if('restore' eq $mode){
      &cipux_task_restore_user_homedir('cgi',$cipux{Cipux_Home_Path},"$in{crole}",$user);
    }
    if('reset' eq $mode){
      &cipux_task_reset_user_homedir('cgi',$cipux{Cipux_Home_Path},"$in{crole}s",$user);
    }
    print "<li>".&text('useradmin_modus',$mode)."</li>";
    print"</ul>";
  }
}

# =========================================================================+
# ||               Add new user (student, theacher)                       ||
# =========================================================================+
if(defined($in{create_user})){
  # useradmin.cgi: - IN: [create_user] = [Benutzer hinzufgen]
  # useradmin.cgi: - IN: [firstname] = [NACH]
  # useradmin.cgi: - IN: [group] = [class84] or []
  # useradmin.cgi: - IN: [login] = [LOGIN]
  # useradmin.cgi: - IN: [password] = [PASS]
  # useradmin.cgi: - IN: [crole] = [student] or [teacher]
  # useradmin.cgi: - IN: [lastname] = [VOR]

  my @args = qw (firstname lastname group login password crole skel);

  my $error = "";
  foreach (@args){
    &log($SCRIPT,"- want arg [$_] with non empty value [$in{$_}]");
    &log($SCRIPT,"  -> ok [$_] is defined") if defined($in{$_});
    if($in{$_} eq ""){
      $error = &text('useradmin_error_01',&text($_));
      # $error = "Bitte geben sie einen Wert f&uuml;r <b>'".&text('$_')."'</b> an!" ;
      &log($SCRIPT,"* ".$error);
      print &cat_error($error);
    }else{
      &log($SCRIPT,"  -> ok [$_] is not empty");
    }
  }
  if($error eq ""){
    my $login     = &conversion_login($in{login});
    my $lastname  = &conversion_name($in{lastname});
    my $firstname = &conversion_name($in{firstname});
    my $password  = &conversion_password($in{password});
    my $group     = &conversion_login($in{group});
    my $skel = $in{skel};
    if($password eq ''){
      # ERROR empty password
      print &cat_print_html_error(12,&text('useradmin_error_12'));
    }else{
      my $uhquota = $ldap{CipUX}{Cipux_Default_User_Hard_Quota};
      my $usquota = &cibot_auto_softquota($uhquota);
      my $ghquota = $ldap{CipUX}{Cipux_Default_Group_Hard_Quota};
      my $gsquota = &cibot_auto_softquota($ghquota);

      print "<li>".&text('create_login',$login)."</li>";
      &log($SCRIPT, "cipux_task_create_user: ('cgi',
			      $login,
			      $firstname,
			      $lastname,
			      $crole,
		              $password,
			      $group,
			      $skel,
			      $uhquota,
			      $usquota,
			      $ghquota,
			      $gsquota)");

      &cipux_task_create_user('cgi',
			      $login,
			      $firstname,
			      $lastname,
			      $crole,
		              $password,
			      $group,
			      $skel,
			      $uhquota,
			      $usquota,
			      $ghquota,
			      $gsquota);
    }
    $letter = uc(substr($login, 0, 1)); # First letter
    &log($SCRIPT,"- the first letter ist now: [$letter]");
    $reread_userlist = 1;
  }
}

# =========================================================================+
#                    Change Posix Account                                 ||
# =========================================================================+
if(defined($in{ps}) and defined($in{u})){
  if($in{a} eq 'enable'){
    &cipux_task_enable_user_posix_account('cgi',$in{u});
  }elsif($in{a} eq 'disable'){
    &cipux_task_disable_user_posix_account('cgi',$in{u});
  }
 print "<hr noshade>";
 print &text('useradmin_changed_status',$in{u})."<br>\n";
 print "<hr noshade>";
}	
# =========================================================================+
#                    Change Samba Account                                 ||
# =========================================================================+
if(defined($in{ss}) and defined($in{u})){
  if($in{a} eq 'enable'){
    &cipux_task_enable_user_samba_account('cgi',$in{u});
  }elsif($in{a} eq 'disable'){
    &cipux_task_disable_user_samba_account('cgi',$in{u});
  }
 print "<hr noshade>";
 print &text('useradmin_changed_status',$in{u})."<br>\n";
 print "<hr noshade>";
}	



# =========================================================================+
#                    User List DATA                                       ||
# =========================================================================+

my $user_href    = &cibot_list('U','uidNumber');# user-nodes's uidNumber
my $urole_href   = &cibot_list('U','cipuxRole');# user-nodes's role
my $crole_href   = &cibot_list('C','cipuxRole');# group-nodes's role
my $u_expire_status_href = &cibot_list('U','cipuxStatus');# user-nodes's expire status (=pending)
my $u_posix_status_href = &cibot_list('U','userPassword');# user-nodes's posix status
my $u_samba_status_href = &cibot_list('U','sambaAcctFlags');# user-nodes's smaba status
my $cipuxFirstname_href = &cibot_list('U','cipuxFirstname');
my $cipuxLastname_href  = &cibot_list('U','cipuxLastname');

foreach my $login (sort keys %$user_href){
  &log($SCRIPT, "- login [$login] urole [$$urole_href{$login}] crole [$$crole_href{$login}]");
  push(@login,$login) if $$urole_href{$login} ne 'share';

  # to save some skels (but only account/skel not role/skel)
  # like cycle1 but not student, teacher, ...
  if($$crole_href{$login} eq 'skel'
    and $$urole_href{$login} eq 'account'){
    &log($SCRIPT,"- [$login] eq skel => add $login to @skel");
    push(@skel,$login);
  }

  # to save some groups
  if($$crole_href{$login} eq 'course'){
    &log($SCRIPT,"- [$login] eq course => add $login to @course");
    push(@course,$login);
  }

  # delete unused hashes
  if($$urole_href{$login} ne 'account'
    or (
        $$urole_href{$login} eq 'account'
        and $$crole_href{$login} eq 'skel'
       )
    or (
       $$u_expire_status_href{$login} ne 'pending'
       and $SCRIPT eq 'apply_applicationform.cgi'
       )
   ){
    &log($SCRIPT,"- [$login] eq account => delete $login");
    delete($$user_href{$login});
    delete($$cipuxFirstname_href{$login});
    delete($$cipuxLastname_href{$login});
    delete($$crole_href{$login});
    delete($$urole_href{$login});
    delete($$u_expire_status_href{$login});
    delete($$u_posix_status_href{$login});
    delete($$u_samba_status_href{$login});
  }else{
    my $l = uc(substr($login, 0, 1)); # A=1
    $abc{$l}=1;
  }
}

my @abc = sort @login;
if(not defined($letter)){
  $letter = uc(substr($abc[0], 0, 1)); # assign the first known letter;
  &log($SCRIPT,"-  first letter is now [$letter]");
}

# =========================================================================+
#                           Set Quota                                     ||
# =========================================================================+

&log($SCRIPT,"- user [$user] action [$action] - [".&text('set')."]");

if($uidNumber ne "" and $action eq &text('set')){
  my $fs = $cipux{Cipux_Quota_Filesystem};
  print "<ul><li>".&text('set_user_quota_to',$fs,$size)."</li>";
  &log($SCRIPT,"- calling: &cibot_set_quota($fs,$uidNumber,$size,0);");
  &cibot_set_quota($fs,$uidNumber,$size,0);# 0 = userquota
  print &cat_action_status([&text('user_quota_was_set_to',$uidNumber,$size)]);
  if($ldap{CipUX}{Cipux_Default_Group_Hard_Quota} > 0){ # set group quota
    print "<li>".&text('set_group_quota_to',$fs,$size)."</li>";
    &log($SCRIPT,"- calling: &cibot_set_quota($fs,$uidNumber,$size,1);");
    &cibot_set_quota($fs,$uidNumber,$size,1);# 1 = groupquota
    print &cat_action_status([&text('group_quota_was_set_to',$uidNumber,$size)]);
  }else{
      print "<li>".&text('qroup_quota_turned_off')."</li>";
  }
  print "</ul>";
  #print &cat_action_status([""]) if $ldap{CAT}{Cat_Status_Messages};
}

# =========================================================================+
# | =                    "Delete user and homedir question";#           ||
# =========================================================================+
if($user ne "" and $a eq &text('useradmin_d')){
  $dialog=1;
  &log($SCRIPT,"- deletion");
  print "<br><br>";
  print &text('useradmin_reset_question',$user);
  print "<br>";
  print "<form method=post a='useradmin.cgi'>";
  print "<input type=hidden name=u value=\"$user\" >";
  print "<input type=submit name=a value=\"".&text('deletion')."\"> ";
  print "<input type=submit name=a value=\"".&text('chancel')."\"> ";
  print "</form>";
}

# =========================================================================+
# | =                    "Backup user data";#                           ||
# =========================================================================+

if($uid ne "" and $a eq &text('useradmin_b')){
  print "<b>back up the homedir of $uid</b>:";
  &cipux_task_backup_user_homedir($uid);
}

# =========================================================================+
# | =                    "Extend user account";#                        ||
# =========================================================================+
if($expires_feature){# FIXME TODO

if($u ne "" and $a eq &text('useradmin_e') and $e ne ""){
  # TODO: Source this into a script

  my $expire_date = next_expires($Cipux_Ldap_Next_Expire_Date);

  my @cmd=();
  push(@cmd,"/usr/local/cipux/cibot/bin/set_value.pl "
           ."-e $cipux{Cipux_Ldap_Accout_Flags_Attr} "
           ."-v '$cipux{Cipux_Ldap_Samba_enabled}' -u $u");
  push(@cmd,"/usr/local/cipux/cibot/bin/set_value.pl "
           ."-e $cipux{Cipux_Ldap_Warning_Attr} "
           ."-v '$cipux{Cipux_Ldap_Warning_enabled}' -u $u");
  push(@cmd,"/usr/local/cipux/cibot/bin/set_value.pl "
           ."-e $cipux{Cipux_Ldap_Expire_Attr} "
           ."-v '$expire_date' -u $u");
  push(@cmd,"/usr/local/cipux/cibot/bin/set_value.pl "
           ."-e $cipux{Cipux_Ldap_Last_Warning_Attr}"
           ."-v '$cipux{Cipux_Ldap_Last_Warning_Value}' -u $u");

  foreach (@cmd){
    &log($SCRIPT,"CMD: '$_'");
    open(CMD,"$_ |") or die print "Can't execute '$_'! \n";
    my @output=<CMD>;
    close(CMD);
  }

  print &text('useradmin_changed_expire_date')." <b>$u</b> ";
  print &text('useradmin_changed_expire_date_till')." '$expire_date'! (YYYY-MM-DD)<br>";
}

}# FIXME

# =========================================================================+
# | =                    "Change status";#                              ||
# =========================================================================+
if(defined($in{change_status})){
  &log($SCRIPT," * change status");


}		


# TODO: FIXME START
# if($u ne "" and $a eq "status"){
if($u ne "" and $a eq &text('useradmin_s')){

  my $g_cmd="/usr/local/cipux/cibot/bin/get_value.pl -u $u -e $cipux{Cipux_Ldap_Accout_Flags_Attr}";
  my $s_cmd="/usr/local/cipux/cibot/bin/set_value.pl -u $u -e $cipux{Cipux_Ldap_Accout_Flags_Attr}";
  &log($SCRIPT,"CMD '$g_cmd'<br> '$s_cmd<br>'");
  &log($SCRIPT,"DIS: $cipux{Cipux_Ldap_Samba_disabled} ");
  &log($SCRIPT,"EN : $cipux{Cipux_Ldap_Samba_enabled} ");
  open(CMD,"$g_cmd |") or die print "Can't execute '$g_cmd'! \n";
    while(<CMD>){
      if($_ ne ""){
        $value=$_;
      }
    }
  close(CMD);
  #
  &log($SCRIPT,"VALUE $value");
  if($value =~ m/U/){
    $cmd="$s_cmd -v '$cipux{Cipux_Ldap_Samba_disabled}'";
  }else{
    $cmd="$s_cmd -v '$cipux{Cipux_Ldap_Samba_enabled}'";
  }
  #
  &log($SCRIPT,"CMD: $cmd");
  open(CMD,"| $cmd") or die print "Can't execute '$cmd'! \n";

  close(CMD);
  print "<hr noshade>";
  print &text('useradmin_changed_status')." '$u'!<br>\n";
  print "<hr noshade>";
}
# TODO: FIXME END

# =========================================================================+
# | =                    "Change password";#                            ||
# =========================================================================+
if(defined($in{submit_password})){
  &log($SCRIPT,"* submit_password");
  my $password = &conversion_password($in{pwd});
  if($password ne ""){
    &log($SCRIPT,"- password is NOT empty");
    # test for non asci chars!
    if($password =~ m/_/ or $password =~ m/_+/ or $password =~ m/\W+/ or $password =~ m/'+/){
      &cat_error_info_dialog($SCRIPT,
			     &text('passwort_problem_01'),
			     &text('passwort_problem_02'),
			     ,$user,$crole,'dummy',$letter);
      $dialog=1;
    }else{
      &log($SCRIPT,"- password contain probably no bad chars");
      print "<ul><li>".&text('useradmin_set_password_for_login_to',
			     $user,$password)."</li></ul>";
      &cipux_task_change_user_password('cgi',$user,$password);
    }
  }else{
      &cat_error_info_dialog($SCRIPT,
			     &text('passwort_problem_01'),
			     &text('passwort_problem_03'),
			     ,$user,$crole,'dummy',$letter);
      $dialog=1;
  }
}

# +========================================================================+
# ||  Main                                                                ||
# +========================================================================+

if($dialog){
  # reset or restore, ....

}else{
  # =========================================================================+
  # ||                        PRINT USER LIST                               ||
  # =========================================================================+

  print "<h2>".&text($SCRIPT)."</h2>";

  &log($SCRIPT,"print userlist ...");

  print &cat_abc_nav($SCRIPT,\%abc);

  my $multicol= '';
  if($SCRIPT eq 'useradmin.cgi'){
    $multicol = &text('directory');
  }else{
    $multicol = &text('application');

  }	  
  if($cipux{CipUX_Quota}){
    my $title = &text('known_applicants',$letter);
    $title = &text('useradmin_known_user',$letter) if $SCRIPT eq 'useradmin.cgi';
    print &cat_table_header(9,$tb,$title);
    print &cat_table_row([1,1,1,1,1,1,1,1,1],
	  	       [$tb,$tb,$tb,$tb,$tb,$tb,$tb,$tb,$tb],
		       [&text('login'),
                        &text('user'),
			&text('role'),
			&text('status'),
			&text('disk_usage'),
			&text('hard_quota'),
			&text('password'),
			$multicol,
			&text('login')]);
  }else{
    print &cat_table_header(7,$tb,$title);
    print &cat_table_row([1,1,1,1,1,1,1],
		       [$tb,$tb,$tb,$tb,$tb,$tb,$tb],
		       [&text('login'),
                        &text('user'),
			&text('role'),
			&text('status'),
			&text('password'),
			$multicol,
			&text('login')]);
  }

  foreach my $u (sort keys %$user_href){

    &log($SCRIPT,"  -> user [$u] ...");
    my $l = uc(substr($u, 0, 1));
    &log($SCRIPT,"letter: $l ($letter) user: $u  $uid: $$user_href{$u}");

    if($letter eq $l){

      # user name	    
      my $username = "$$cipuxFirstname_href{$u} $$cipuxLastname_href{$u}";

      # user role

      # user status
      my $status = '';
      # posix system
      if($ldap{CipUX}{CipUX_Linux_Client_System}){
        if($$u_posix_status_href{$u} =~ m/DISABLED/ and $ldap{CipUX}{CipUX_Linux_Client_System}){
          $status .= " <a href='/cat/$SCRIPT?ps=1&u=$u&a=enable' title='".&text('posix_status')."'>";
          $status .= "<img src='images/c.png' align=middle alt='".&text('disabled')."' border=0></a>";
        }else{
          $status .= " <a href='/cat/$SCRIPT?ps=1&u=$u&a=disable' title='".&text('posix_status')."'>";
          $status .="<img src='images/r.png' align=middle alt='".&text('enabled')."' border=0></a>";
        }
      }
      # samba system
      if($$u_samba_status_href{$u} =~ m/D/ and $cipux{Cipux_Use_Samba} eq 'yes'){
        $status .= " <a href='/cat/$SCRIPT?ss=1&u=$u&a=enable' title='".&text('samba_status')."'>";
        $status .= "<img src='images/c.png' align=middle alt='".&text('disabled')."' border=0></a>" 
      }else{
        $status .= " <a href='/cat/$SCRIPT?ss=1&u=$u&a=disable' title='".&text('samba_status')."'>";
        $status .= " <img src='images/r.png' align=middle alt='".&text('enabled')."' border=0></a>" 
      }
      # expire system
      if($ldap{CipUX}{CipUX_Expire_System}){
        $status .= " <a href='/cat/userdata.cgi?login=$u' title='".&text('expire_status')."'>";
        if($$u_expire_status_href{$u} eq 'pending'){
  	      #<a href='/cat/$SCRIPT' title='".&text('pending')."'>
	      #<img src='images/w.png' align=middle alt='".&text('pending')."' border=0>
	      #</a>";
          $status .= "<img src='images/w.png' align=middle alt='".&text('pending')."' border=0>";
        }elsif($$u_expire_status_href{$u} eq 'alerting'){
	  $status .= "<img src='images/c.png' align=middle alt='".&text('alerting')."' border=0>";
        }elsif($$u_expire_status_href{$u} eq 'idle'){
	  $status .= "<img src='images/r.png' align=middle alt='".&text('idle')."' border=0>";
        }else{
	  $status .= "<img src='images/u.png' align=middle alt='".&text('unknown')."' border=0>";
        }
	$status .= "</a>";      
      }	
      
      # Quota System
      $quota_message = '';
      my $max_quota= '';
      if($cipux{CipUX_Quota}){
        my $fs = $cipux{Cipux_Quota_Filesystem};
        &log($SCRIPT,"- calling: &cibot_get_quota($fs, $$user_href{$u},$quotatype) ");
        my ($bc,$bs,$bh,$bt,$ic,$is,$ih,$it) = &cibot_get_quota($fs,$$user_href{$u},$quotatype);
	$max_quota = $bh;

        &log($SCRIPT,"- calling: \$quota_message = &cat_quota_usage_cols($bc,$bs,$bh,$bt,$ic,$is,$ih,$it)");
        $quota_message = &cat_quota_usage_cols($bc,$bs,$bh,$bt,$ic,$is,$ih,$it);
        &log($SCRIPT,"- \$quota_message: [$quota_message]");
      }

      
      my $userlink = "<a href='userdata.cgi?login=$u'>$u</a>";
      
      # user dir/ change status
      my $multifunc ='';
      if($SCRIPT eq 'useradmin.cgi'){
         $multifunc ="<input type=submit name='useradmin_restore_homedir' value='".
	 &text('to_restore').
	 "'><input type=submit name='useradmin_reset_homedir' value='".
	 &text('to_reset').
	 "'>";
      }else{
	      #  $multifunc = "<input type=submit name=change_status value='".&text('change')."'>";
        $multifunc = "<a href='/cat/userdata.cgi?login=$u'>".&text('change')."</a>";

      }
      
      # delete user
      my $delete = " <input type=submit name=useradmin_delete_user value='".&text('delete')."'>";
      $delete = &text('default') if $u eq 'cipadmin' or $$urole_href{$u} ne "account";

      print "<form method=post action='$SCRIPT'>
        <input type=hidden name=user value=\"$u\" >
        <input type=hidden name=urole value=\"$$urole_href{$u}\">
        <input type=hidden name=crole value=\"$$crole_href{$u}\">";
      print "<input type=hidden name=letter value=\"$letter\">" if defined($letter);

      if($cipux{CipUX_Quota}){
	&log($SCRIPT,"- \$u = [$u] \$\$user_href{\$u} = [$$user_href{$u}], \$max_quota = [$max_quota]");      
	my $string = &cat_quota_set_col($SCRIPT,"uidNumber",$$user_href{$u},$max_quota);      
	&log($SCRIPT,"\$string = [$string]");      
        print &cat_table_row(
                         [1,0,0,0,0,0,0,0,0],
			 [$tb,'','','','',$cb,$cb,$cb,$cb],
			 [
			  "$userlink",
                          $username,
			  &text($$urole_href{$u})."/ ".&text($$crole_href{$u}),
			  $status,
			  $quota_message,
			  &cat_quota_set_col($SCRIPT,"uidNumber",$$user_href{$u},$max_quota),
			  &cat_open_passwd_col($SCRIPT,'userPassword',''),
			  $multifunc,
			  $delete
			 ]);
      }else{
        print &cat_table_row(
                         [1,0,0,0,0,0,0],
			 [$tb,'','','',$cb,$cb,$cb],
			 [
			  $userlink,
                          $username,
			  &text($$urole_href{$u})."/ ".&text($$crole_href{$u}),
			  $status,
			  &cat_open_passwd_col($SCRIPT,'userPassword',''),
			  $multifunc,
			  $delete
			 ]);
      }
    print "</form>";
  }
}

print &cat_table_footer;

if($SCRIPT eq 'useradmin.cgi'){
  #print "<table width='90%'><tr><td align=top>";
  print_add_user(&text('add_new_object',&text($cipux{Cipux_User1})),&text($cipux{Cipux_Course}),"public","student");
  #print "</td><td align=top>";
  print_add_user(&text('add_new_object',&text($cipux{Cipux_User3})),&text($cipux{Cipux_Course}),"public","teacher");
  #print "</table>";
  print_add_user(&text('add_new_object',&text($cipux{Cipux_User4})),&text($cipux{Cipux_Course}),"public","guest");
}
}

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+

&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);

# +========================================================================+
# || print_add_user                                                       ||
# +========================================================================+
sub print_add_user{
  my $title = shift;
  my $type_name = shift;# ???
  my $group_type = shift;# OLD: school_class, authority_group NEW: private, public, shared
  my $role_type = shift;# cipuxRole = admin, assistant, teacher, student, guest


  my $groups = "<select name='group' size=1>\n<option>";

  #TODO: if you add this, a guest is created!
  #push(@course,'none');

  $groups .= join("</option>\n<option>",@course);
  $groups .= "</option>\n</select>\n";

  my $skels = "<select name='skel' size=1>\n<option>";
  push(@skel,'none');
  $skels .= join("</option>\n<option>",@skel);
  $skels .= "</option>\n</select>\n";

  print "<br><form method=post action='$SCRIPT'>";
  print "<input type=hidden name=crole value=\"$role_type\" >";
  print &cat_table_header(2,$tb,$title);
  print &cat_table_row([1,0],
		       [$tb,$cb],
		       [&text('login'),"<input type=text name='login' maxlenght=20 size=24>"]);
  print &cat_table_row([1,0],
		       [$tb,$cb],
		       [&text('cipuxFirstname'),"<input type=text name='firstname' maxlenght=60 size=24>"]);
  print &cat_table_row([1,0],
		       [$tb,$cb],
		       [&text('cipuxLastname'),"<input type=text name='lastname' maxlenght=60 size=24>"]);
  print &cat_table_row([1,0],
		       [$tb,$cb],
		       [&text('password'),"<input type=text name='password' maxlenght=60 size=24>"]);
  if($role_type eq "student"){
    print &cat_table_row([1,0],[$tb,$cb],[$type_name,$groups]);
    print &cat_table_row([1,0],[$tb,$cb],[&text('initial_default_values'),$skels]);
  }else{
    print "<input type=hidden name=\"group\" value=\"none\" >";
    print "<input type=hidden name=\"skel\" value=\"none\" >";

  }
  print &cat_table_footer;
  print "<input type=submit value='".&text('add_user')."' name='create_user'></form>";
}
