#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: cipuxadmin.cgi                                        ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package cipuxadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "cipuxadmin.cgi";

# for this Version 3.2.0 beta, we have to disable this
my %disabled = ( Cipux_Producer                  => 1,
		 Cat_Feature_Application_Apply 	 => 1,
		 Cat_Feature_Application_Form 	 => 1,
		 Cat_Feature_Clientadmin 	 => 1,
		 Cat_Feature_Hardwareadmin 	 => 1,
		 Cat_Feature_Imagematrixadmin 	 => 1,
		 Cat_Feature_Mailadmin 	         => 1,
		 Cat_Feature_Roomadmin 	         => 1,
		 Cat_Feature_Softwareadmin 	 => 1,
		 Cat_Status_Messages 	         => 1
 );

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

#if($result ne 'ok'){
#  print "<h1>$text('access_denied')}</h1>";
#  #print $text('access_denied_explanation',$remote_user,$role);
 # &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
 # exit(0);
#}
                        ;
my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);


# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

my $system = $in{'system'}    if defined($in{'system'});# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

my %roles = ();
my @roles = `cipux_task_list_roles`;
foreach(@roles){chomp;$roles{$_}=1}

# =========================================================================+
#                    Config                                               ||
# =========================================================================+
if(defined($in{change_cipux_variable})
   and defined($in{system})
   and defined($in{cipux_variable})
   and defined($in{cipux_variable_value})){
  &log($SCRIPT,"* change_cipux_variable");

  # for cipadmin GUI
  $in{cipux_variable_value}=1 if $in{cipux_variable_value} eq 'enabled';
  $in{cipux_variable_value}=0 if $in{cipux_variable_value} eq 'disabled';


  if($in{cipux_variable} =~ m/Acl/){
    &log($SCRIPT,"- check given ACL [$in{cipux_variable_value}]");

    $in{cipux_variable_value} =~ s/^\s+//g;
    $in{cipux_variable_value} =~ s/\s+$//g;

    # $#i > 0  (i = input)
    my @i = split(/\s+/,$in{cipux_variable_value});
    &log($SCRIPT,"- array length [$#i]");

    # $#i == 0
    push(@i,$in{cipux_variable_value}) if $#i == 0; # one element
    # $#i < 0
    push(@i,'') if $#a == -1; # undef -> def

    # MATCHING = grep { TEST ($_) } @LIST;
    my @matching = grep { $roles{$_} } @i;

    foreach(keys %roles){
      &log($SCRIPT,"- roles  [$_]");
    }
    foreach (@matching){
      &log($SCRIPT,"- matching  [$_]");
    }
    my %seen = ();
    my @uniqu = grep { ! $seen{$_} ++ } @matching;
    foreach (@uniqu){
      &log($SCRIPT,"- u  [$_]");
    }
    $in{cipux_variable_value}='';
    $in{cipux_variable_value}=join(' ',@uniqu);
    &log($SCRIPT,"- write  [$in{cipux_variable_value}]");
  }
  my $value = "$in{cipux_variable}=$in{cipux_variable_value}";
  &cipux_task_change_cipux_config_variable_value('cgi',$in{system},$value);
}

#my $group_href = &cibot_list('X','cipux');# list all group's gidNumber

# only in this CGI!
&cibot_get_cipux_config("/etc/cipux/cipux.conf");

# this in every CGI, where it is ok
&cibot_get_ldap_config();

# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+
print "<h2>".&text('configuration')." ($remote_user as $role)</h2>";

#my $role = 'root';
if($remote_user eq 'root'){
  foreach my $system (sort keys %ldap){
    # print "<form method=post action='$SCRIPT'>";
    print &cat_table_header(2,$tb,&text('cipux_configuration').": $system");
    print &cat_table_row([1,1],
		       [$tb,$tb],
		       [&text('variable'),&text('value')]);

    foreach my $variable (sort keys %{$ldap{$system}}){
      if(not defined($disabled{$variable})){
        print &cat_table_row([1,0,],
			   [$tb,$cb],
			   [$variable,&cat_cipux_variable_col($SCRIPT,
							      'cipux_variable',
							      $variable,$ldap{$system}{$variable},
							      $system)]
			  );
      }
    }

    print &cat_table_footer ."<br>";
    #  print "</from>";
  }
}elsif($remote_user eq 'cipadmin'){

#  my $system = "Structure";

#  if($ldap{Structure}{Structure_Levels} == 0
#    or $ldap{Structure}{Structure_Rows} ==0 ){
#    print "<h1>CipUX Setup:</h1>";
#    print &cat_explain_message(&text('cipuxadmin_setup_01'));
#    print "<form method=post action='cipuxadmin.cgi'>";
#    print &cat_table_header(2,$tb,&text('cipux_configuration').": $system");
#    my $l = &cat_cipux_variable_col(
#       $SCRIPT,
#       'cipuxadmin_leves',
#       ' cipuxadmin_leves_var',
#       '0',$system);
#    print &cat_table_row([1,1],
#		       [$tb,$tb],
#		       ['cipuxadmin_leves',$l]);
#    my $r = &cat_cipux_variable_col(
#       $SCRIPT,
#       'cipuxadmin_leves',
#       ' cipuxadmin_leves_var',
#       '0',$system);
#
#    print &cat_table_row([1,1],
#		       [$tb,$tb],
#		       ['cipuxadmin_rows',$r]);
#    print &cat_table_footer ."<br>";
#    print "<input type=submit name=setup_structure value=\"".&text('save')."\"> ";
#    print "</form>";
#
#  }else{





  $system = "CAT";
  foreach(@roles){chomp}
  my $roles = join(', ',@roles);
  print cat_explain_message(&text('the_following_roles_exists',"<b>$roles</b>"));
  print &cat_table_header(4,$tb,&text('cipux_configuration').": $system");
  print &cat_table_row([1,1,1,1],
		       [$tb,$tb,$tb,$tb],
		       ['&nbsp;',
		         &text('module'),
		         &text('acl'),
		         &text('access')]);

  foreach my $variable (sort keys %{$ldap{$system}}){
    #$variable = Cat_Feature_Acladmin
    # png: cipux_acldmin.png
    if(not defined($disabled{$variable}) and $variable =~ /Feature/){


      my $png = lc($variable);
      $png =~ s/cat_feature/cipux/g;
      $img = "<img src='images/".$png.".png'> ";

      my $t = lc($png); # for the title
      $t =~ s/cipux_//g;
      $t .= ".cgi";

      my $acl_variable = $variable;
      $acl_variable =~ s/_Feature_/_Acl_/g;
      my $acl_value = $ldap{CAT}{$acl_variable};
      $acl_value = '' if not defined($acl_value);


      my @choice = qw(disabled enabled);
      my $choice = "<form method=post action='cipuxadmin.cgi'>";
      $choice .= "<input type=hidden name=cipux_variable value=\"$variable\" >";
      $choice .= "<input type=hidden name=system value=\"CAT\" >";

      $choice   .= " <select name='cipux_variable_value' size=1>";
      foreach (@choice){
        if($ldap{$system}{$variable} eq 1){
          $choice .= "<option selected value='$_'>".&text($_)."</option>\n";
        }else{
          $choice .= "<option value='$_'>".&text($_)."</option>\n";
        }
      }
      $choice  .= "</select>";
      $choice  .= "<input type=submit name=change_cipux_variable value=\"".&text('save')."\"> ";
      $choice  .= "</form>\n";
      $choice  = '' if $variable eq 'Cat_Feature_Cipuxadmin';
      my $acl  = &cat_cipux_variable_col($SCRIPT,
                                         'cipux_variable',
					 $acl_variable,$acl_value,
					 $system);
      $acl = '' if $variable eq 'Cat_Feature_Cipuxadmin';
      # &cat_cipux_variable_col($SCRIPT,'cipux_variable',
      #$variable,$ldap{$system}{$variable},
      #$system)
      print &cat_table_row([1,1,0,0],
			   ['','',$cb,$cb],
			   [$img,"$t",$acl,$choice]
			  );
    }
  }

  print &cat_table_footer ."<br>";
    #  print "</from>";
  

}else{

  print &text('access_denied_only_access_for_root_or_cipadmin');
  # What should they see?

}

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);

