#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: examadmin.cgi                                         ||
# || for administration of examina an exam-groups                         ||
# || (c) 2005 Christian Kuelker                                           ||
# || License: GPL                                                         ||
# +========================================================================+

package examadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Conversion;
use CipUX::Task;
use CipUX::Cat;

my $BRAND   = "cipworx";
my $PROJECT = "cipux";
my $SCRIPT  = "examadmin.cgi";

my @add = qw(groupname gpasswd upasswd room teacher gsize usize);
my $dialog = 0;

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

my $action = $in{'action'} if defined($in{'action'});# action

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

# =========================================================================+
# ||                 START                                                ||
# =========================================================================+
if(defined($in{submit_start})){
  if(defined($in{group})){
    &cipux_task_start_exam('cgi',$in{group},$in{teacher});
  }else{
    &log($SCRIPT,"ERROR: \$in{group} is not defined!! Check the script!!");
  }
}

# =========================================================================+
# ||                 COLLECT                                              ||
# =========================================================================+
if(defined($in{submit_collect})){
  if(defined($in{group})){
    &cipux_task_collect_exam('cgi',$in{group},$in{teacher});
  }else{
    &log($SCRIPT,"ERROR at submit_collect : \$in{group} is not defined!! Check the script!!");
  }
}

# =========================================================================+
# ||                 END                                                  ||
# =========================================================================+
if(defined($in{submit_end})){
  if(defined($in{group})){
    &cipux_task_end_exam('cgi',$in{group}, $in{teacher});
  }else{
    &log($SCRIPT,"ERROR at submit_end : \$in{group} is not defined!! Check the script!!");
  }
}

# =========================================================================+
# ||                 DEL                                                  ||
# =========================================================================+
if(defined($in{submit_del})){
  &log($SCRIPT,"+ submit_del");
  if(defined($in{group})){
    &log($SCRIPT,"- got group [$in{group}]");
    # Members: ./get_value.pl -c biologie -e memberUid
    # DEL GROUP: physik
    # DEL USERS FOR THAT GROUP: physic01 till physic32
    #my $cmd = "/usr/local/cipux/cibot/bin/get_value.pl -c '$in{group}' -e memberUid";
    my $member_href = &cibot_list("c '$in{group}'","memberUid");
    my $groups_href = &cibot_list("C","cn");
    my $users_href  = &cibot_list("U","uid");

    print "<ul>";
    foreach my $m (keys %$member_href){
      if(defined($$users_href{$m})){
	&log($SCRIPT,"- may delete member uid [$m]");
	if($m =~ m/$in{group}\d{1,2}$/){
	  &log($SCRIPT,"- delete member uid [$m]");
	  print "<li>".&text('delete_login',$m)."</li>";
	  &cipux_task_delete_user('cgi',$m);
	}else{
	  &log($SCRIPT,"- other uid (not part of exam group) [$m] not deleted");
	  print "<li>".&text('delete_not_login',$m)."</li>";
	}
      }else{
	&log($SCRIPT,"- member uid [$m] already non existent");
	print "<li>".&text('examadmin_login')." <b>$m</b> ".
	  &text('examadmin_delete_failed')."</li>";
      }
      if(defined($$groups_href{$m})){
	&log($SCRIPT,"- may delete member gid private group [$m]");
	if($m =~ m/$in{group}\d{1,2}$/){
	  &log($SCRIPT,"- delete member gid private group [$m]");
	  print "<li>".&text('delete_private_group',$m)."</li>";
	  #&cipux_task_delete_course($m); # TODO: Mit delete_user verbinden!
	  	}else{
	  &log($SCRIPT,"- other gid (not part of exam group) [$m] not deleted");
	  print "<li>".&text('delete_not_group',$m)."</li>"
	}
      }else{
	&log($SCRIPT,"- private group [$m] already non existent");
	print "<li>".&text('examadmin_private_group')." <b>$m</b> ".
	  &text('examadmin_delete_failed')."</li>";
      }
    }
    $groups_href = &cibot_list("C","cn");
    if(defined($$groups_href{$in{group}})){
      &log($SCRIPT,"- delete examination uid [$in{group}]");
      print "<li>".&text('delete_examination_login',$in{group})."</li>";
      &cipux_task_delete_user('cgi',$in{group})
      &log($SCRIPT,"- delete examination group [$in{group}]");
      print "<li>".&text('delete_examination_group',$in{group})."</li>";
    }else{
      &log($SCRIPT,"- exam group [$m] already non existent");
      print "<li>".&text('examadmin_examination_group')." <b>$m</b> "
	.&text('examadmin_delete_failed')."</li>";
    }
    print "</ul>";
    #    &cibot_exec_cmd('html',$cmd,"See the Skript.")
  }else{
    &log($SCRIPT,"ERROR at submit_del : \$in{group} is not defined!! Check the script!!");
  }
}

# +========================================================================+
# ||     CONFIRM NEW GROUP                                                ||
# +========================================================================+
if(defined($in{examadmin_submit_new})){
  my $error = 0;
  $in{upasswd}=&conversion_password($in{upasswd});
  $in{gpasswd}=&conversion_password($in{gpasswd});
  $in{groupname}=&conversion_login($in{groupname});
  $in{gsize}=&conversion_integer($in{gsize});
  $in{usize}=&conversion_integer($in{usize});
  foreach $var (@add){
    # print " [$var] <br>";
    $error = 1 if not defined($in{$var});
  }
  if(not $error){
    foreach $var (@add){
      # print " [$var] [$in{$var}]<br>";
      $error = 1 if $in{$var} eq "";
    }
  }
  if($error){
    if($in{upasswd} ne '' and $in{gpasswd} ne ''){
      # ERROR: missing_data
      &cat_error_info_dialog($SCRIPT,
			     &text('examadmin_error_1a'),
			     &text('examadmin_error_1b'),$user,$role,'dummy',$letter);
    }else{
      # ERROR no meaningful password
      &cat_error_info_dialog($SCRIPT,
			     &text('examadmin_error_2a'),
			     &text('examadmin_error_2b'),$user,$role,'dummy',$letter);
    }
  }else{
    my $gpasswdf = $in{gpasswd};
    my $upasswdf = $in{upasswd};
    # TODO:
    $gpasswdf =~ s/./*/g;
    $upasswdf =~ s/./*/g;
    &cat_confirm_dialog($SCRIPT,
			&text('examadmin_confirm_group'),
			&text('examadmin_confirm_group_question')."
  <table border=0>
   <tr><td>".&text('examadmin_confirm_group_name').":</td><td> <b>$in{groupname}</b></td></tr>
   <tr><td>".&text('examadmin_confirm_group_group_password').":</td><td> <b>$in{gpasswd}</b></td></tr>
   <tr><td>".&text('examadmin_confirm_group_numbers').":</td><td> <b>$in{room}</b></td></tr>
   <tr><td>".&text('examadmin_confirm_group_teacher').":</td><td> <b>$in{teacher}</b></td></tr>
   <tr><td>".&text('examadmin_confirm_group_max_group_quota').":</td><td> <b>$in{gsize}</b></b></td></tr>
   <tr><td>".&text('examadmin_confirm_group_max_user_quota').":</td><td> <b>$in{usize}</b></td></tr>
   <tr><td>".&text('examadmin_confirm_group_user_password').":</td><td><b>$in{upasswd}</b></td></tr>
</table>
  <input type=hidden name=groupname  value=\"$in{groupname}\">
  <input type=hidden name=gsize      value=\"$in{gsize}\">
  <input type=hidden name=usize      value=\"$in{usize}\">
  <input type=hidden name=teacher    value=\"$in{teacher}\">
  <input type=hidden name=room       value=\"$in{room}\">
  <input type=hidden name=gpasswd    value=\"$in{gpasswd}\">
  <input type=hidden name=upasswd    value=\"$in{upasswd}\">
",$user,$role,'examadmin_submit_new_ok',&text('chancel'));
  }
 $dialog = 1;
}

# +========================================================================+
# ||     NEW GROUP                                                        ||
# +========================================================================+
if(defined($in{examadmin_submit_new_ok})){
  &log($SCRIPT,"* examadmin_submit_new");
  #examadmin.cgi: - IN: [examadmin_submit_new_ok] = [OK]
  #examadmin.cgi: - IN: [gpasswd] = [asd]
  #examadmin.cgi: - IN: [groupname] = [Physik]
  #examadmin.cgi: - IN: [gsize] = [1000002]
  #examadmin.cgi: - IN: [letter] = []
  #examadmin.cgi: - IN: [role] = []
  #examadmin.cgi: - IN: [room] = ['01'..'16']
  #examadmin.cgi: - IN: [teacher] = [teacherlogin]
  #examadmin.cgi: - IN: [upasswd] = [5345]
  #examadmin.cgi: - IN: [user] = []
  #examadmin.cgi: - IN: [usize] = [100012]
  my $groupname = &conversion_login($in{groupname});
  my $firstname = &conversion_name($in{firstname});
  my $lasttname = &conversion_name($in{lastname});
  my $upasswd = &conversion_password($in{upasswd});
  my $gpasswd = &conversion_password($in{gpasswd});
  my $gsize = &conversion_integer($in{gsize});
  my $usize = &conversion_integer($in{usize});
  my $teacher = &conversion_login($in{teacher});

  my @range = (eval($in{room}));

  my $groups_href = &cibot_list("C","cn");
  my $users_href = &cibot_list("U","uid");

  print "<ul>";
  # create exam group
  if(not defined($$groups_href{$groupname})){
    print "<li>".&text('examadmin_create_examination_group').": <b>$groupname</b></li>";
    &cipux_task_create_examination_course('cgi',
	                                  $groupname,
					  $teacher,
					  $gpasswd,
					  $gsize,
					  &cibot_auto_softquota($gsize));
  }else{
    print "<li>".&text('group_already_exist',$groupname)."</li>";
  }

  # add exam uid
  if(not defined($$users_href{$groupname})){
    print "<li>".&text('examadmin_create_examination_user').": <b>$groupname</b></li>";
    # should be done above
  }else{
    print "<li>".&text('login_already_exist',$groupname)."</li>";
  }

  # add teacher uid to exam group
  print "<li>".&text('add_login_to_group',$teacher,$groupname)."</li>";
  &cipux_task_add_user_to_course('cgi',$groupname,$teacher);

  # add uid to examinee
  print "<li>".&text('add_login_to_group',$groupname,'examinees')."</li>";
  &cipux_task_add_user_to_course('cgi',$examinees,$groupname);

  foreach my $r (@range){
    # create private group 01..nn
    if(not defined($$groups_href{"$groupname$r"})){
      print "<li>".&text('create_private_group',"$groupname$r")."</li>";
      # TODO; do we need this?:         ." --attribute cipuxGroupLeaderUid='$teacher'"
      # cgi UID Firstname Lastname Role Passwd Default_CID Skel_Uid uhq usq ghq gsq
      &cipux_task_create_user('cgi',
			      "$groupname$r",
		              $r,
			      $groupname,
			      'examinee',
			      $upasswd,
		              $groupname,
			      'examinee',
			      $usize,
			      &cibot_auto_softquota($usize));


    }else{
      print "<li>".&text('group_already_exist',"$groupname$r")."</li>";
    }

    # create user 00..nn
    if(not defined($$users_href{"$groupname$r"})){
      print "<li>".&text('examadmin_create_examination_member_user')." <b>$groupname$r</b> </li>";
      # TODO: this schould be done above!
    }else{
      print "<li>".&text('login_already_exist',"$groupname$r")."</li>";
    }
    # add user to group
    print "<li>".&text('add_login_to_group',"$groupname$r",$groupname)."</li>";
    &cipux_task_add_user_to_course('cgi',$groupname,"$groupname$r");

    # add uid to examinee
    print "<li>".&text('add_login_to_group',"$groupname$r",'examinees')."</li>";
    &cipux_task_add_user_to_course('cgi','examinees',"$groupname$r");
  }
  print "</ul>";
}

# =========================================================================+
# ||                 Group List                                           ||
# =========================================================================+
my $group_type_href = &cibot_list('C','groupType');#
my $group_teacher_href = &cibot_list("C","cipuxGroupLeaderUid");

# LDAP names of group types and there translation
# authority_group, school_class, private
#my %group = ();
#$group{'school_class'} = "Klasse";
##$group{'authority_group'} = "Verwaltung";# TODO: funzt nicht
#my %group_aref = (); # hash of array refs to store groups

#foreach my $group_type (sort keys %group){
#  &log($SCRIPT,"- get group list [$group_type]");
#  $group_aref{$group_type} = &list_group($group_type);
#}

# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+
if(not $dialog){
  print "<h2>".&text('examadmin_examination')."</h2>";

  print &cat_table_header(6,$tb,&text('examadmin_group_examination'));
  print &cat_table_row([1,1,1,1,1,1],
		       [$tb,$tb,$tb,$tb,$tb,$tb],
		       [&text('examadmin_group'),
			&text('examadmin_leadership'),
			&text('examadmin_examination'),
			&text('examadmin_results'),
			&text('examadmin_examination'),
			&text('examadmin_group')]);
  foreach my $g (sort keys %$group_type_href){
    #  &log($SCRIPT,"  -> [$g]");
    if($$group_type_href{$g} eq "school_exam"){
      print "<form method=post action='$SCRIPT'>";
      #   if($$group_teacher_href{$g} eq "x"){
      #     &log($SCRIPT,"- fixing no cipuxGroupLeaderUid from x to root");
      #     $$group_teacher_href{$g} = "root";
      #     `/usr/local/cipux/cibot/bin/set_value.pl -c $g -e cipuxGroupLeaderUid -v root`;
      #   }
      print "<input type=hidden name=teacher value='$$group_teacher_href{$g}'>";
      print &cat_table_row([1,0,0,0,0,0],[$tb,'',$cb,$cb,$cb,$cb],
			   [
			    $g,
			    $$group_teacher_href{$g},
			    &cat_button_col($SCRIPT,'group',$g,"start",&text('examadmin_start')),
			    &cat_button_col($SCRIPT,'group1',$g,"collect",&text('examadmin_collect')),
			    &cat_button_col($SCRIPT,'group2',$g,"end",&text('examadmin_finish')),
			    &cat_button_col($SCRIPT,'group3',$g,"del",&text('examadmin_delete'))
			   ]);
      print "</form>";
    }
  }
  print &cat_table_footer;

  print "<h2>".&text('examadmin_new_group')."</h2>";

  print "<form method=post action='$SCRIPT'>";
  print &cat_table_header(2,$tb,&text('examadmin_new_group'));
  print &cat_table_row([1,0],[$tb,$cb],
		       [&text('examadmin_new_group_name'),
			"<input type=text maxlength=30 name='groupname' size=20>"]);
  print &cat_table_row([1,0],[$tb,$cb],
		       [&text('examadmin_new_group_password'),
			"<input type=text maxlength=20 name=gpasswd size=10 value=''>"]);
  print &cat_table_row([1,0],
		       [$tb,$cb],
		       [&text('examadmin_new_group_room'),
			"<select name='room' size=1>
                         <option value=\"'01'..'16'\">".&text('examadmin_new_group_left')."</option>
                         <option value=\"'17'..'32'\">".&text('examadmin_new_group_right')."</option>
                         <option value=\"'01'..'32'\">".&text('examadmin_new_group_all')."</option>
                        </select>"
		       ]);

  my $user_href = &cibot_list('U','cipuxRole');
  my @teacher = ();
  foreach my $user (sort keys %$user_href){
    push(@teacher,$user) if $$user_href{$user} eq 'teacher';
  }
  #my $teacher = "<select name='teacher' size=1>\n<option value='teacherlogin'>";
  my $teacher = "<select name='teacher' size=1>\n<option>";
  #$teacher .= join("</option>\n<option value='teacherlogin'>",@teacher);
  $teacher .= join("</option>\n<option>",@teacher);
  $teacher .= "</option>\n</select>\n";
  print &cat_table_row([1,0],[$tb,$cb],[&text('examadmin_new_group_leader'),$teacher]);

  if($ldap{CipUX}{Cipux_Default_Group_Hard_Quota}){
    print &cat_table_row([1,0],
			 [$tb,$cb],
			 [&text('examadmin_new_group_max_group_quota'),
			  "<input type=text maxlength=20 name=gsize size=10 value='$ldap{CipUX}{Cipux_Default_Group_Hard_Quota}'>"]);
  }else{
    print "<input type=hidden name=gsize  value='$ldap{CipUX}{Cipux_Default_Group_Hard_Quota}'>";
  }

  print &cat_table_row([1,0],[$tb,$cb],
		       [&text('examadmin_new_group_max_user_quota'),
			"<input type=text maxlength=20 name=usize size=10 value='$ldap{CipUX}{Cipux_Default_User_Hard_Quota}'>"]);

  print &cat_table_row([1,0],[$tb,$cb],
		       [&text('examadmin_new_group_user_password'),
			"<input type=text maxlength=20 name=upasswd size=10 value=''>"]);

  print &cat_table_footer;
  print "<input type=submit name=examadmin_submit_new  value='".&text('examadmin_submit_new')."'>";
  print "</form>";
  print &cat_explain_message(&text('examadmin_name_advice'),$cb);
}

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);
