#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: groupadmin.cgi                                        ||
# || for administration of groups                                         ||
# || (c) 2001,2002,2003,2005 Christian Kuelker                            ||
# || License: GPLv2 (GPL version two or later)                            ||
# +========================================================================+

package grouapadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Task;
use CipUX::Conversion;
use CipUX::Cat;

my $BRAND   = "cipworx";
my $PROJECT = "cipux";
my $SCRIPT  = "groupadmin.cgi";

my $quotatype = 1; # coursequota

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);


# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

my $action    = $in{'action'}    if defined($in{'action'});# action
my $course    = $in{'course'}    if defined($in{'course'});# course
my $gidNumber = $in{'gidNumber'} if defined($in{'gidNumber'});# action = set
$size         = int($in{'size'}) if defined($in{'size'});# quotasize

# TODO: force $size tobe a reasonable value
$size = 0 if $size < 0 or $size eq "";
&log($SCRIPT,"- \$size = [$size]");

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

# =========================================================================+
#                    Course List                                           ||
# =========================================================================+

# list all course's gidNumber
my $course_href = &cibot_list_courses_with_gidNumber;

# =========================================================================+
#                           Set Quota                                     ||
# =========================================================================+

&log($SCRIPT,"- course [$course] action [$action] - [".&text('set')."]");

if($gidNumber ne "" and $action eq &text('set')){
  my $fs = $cipux{Cipux_Quota_Filesystem};
  &log($SCRIPT,"- calling: &cibot_set_quota($fs,$gidNumber,$size,1);");
  &cibot_set_quota($fs,$gidNumber,$size,1);# coursequota
  &log($SCRIPT,"- calling: &cibot_set_quota($fs,$gidNumber,$size,0);");
  &cibot_set_quota($fs,$gidNumber,$size,0);# userquota
  print &cat_action_status([&text('groupadmin_set_quota_to',$gidNumber,$size)])
    if $ldap{CAT}{Cat_Status_Messages};
}

# =========================================================================+
# | =                    "Change password";#                            ||
# =========================================================================+
if(defined($in{submit_password})){
  &log($SCRIPT,"* submit_password");
  my $password = &conversion_password($in{pwd});
  if($password ne ""){
    &log($SCRIPT,"- password is NOT empty");
    # test for non asci chars!
    if($password =~ m/_/ or $password =~ m/_+/ or $password =~ m/\W+/ or $password =~ m/'+/){
      &cat_error_info_dialog($SCRIPT,
			     &text('passwort_problem_01'),
			     &text('passwort_problem_02'),
			     $in{'course'},$role,'dummy',$letter);
      $dialog=1;
    }else{
      &log($SCRIPT,"- password contain probably no bad chars");
      print "<ul><li>".&text('groupadmin_set_password_for_group_to',
			     $in{'course'},$password)."</li>";
      &cipux_task_change_course_password('cgi',$in{'course'},$password);
      print "</ul>";
    }
  }else{
      &cat_error_info_dialog($SCRIPT,
			     &text('passwort_problem_01'),
			     &text('passwort_problem_03'),
			     $in{'course'},$role,'dummy',$letter);
      $dialog=1;
  }
}

# =========================================================================+
#                           Delete Course                                  ||
# =========================================================================+
if(defined($in{'groupadmin_submit_delete'}) and not $error){#
  &log($SCRIPT,"* delete course [$in{course}]");
  print "<ul>";
  print "<li>".&text('delete_course_login',&text($cipux{Cipux_Course}),$in{'course'})."</li>";
  &cipux_task_delete_course('cgi',$course);
  print "<li>".&text('delete_login',$in{'course'})."</li>";
  print "<li>".&text('group_deleted')."</li>";
  print "</ul>";
}

## =========================================================================+
#$PART =                    "New Course";#                                  ||
## =========================================================================+
&log($SCRIPT,"- recieve new course submit [$in{&text('groupadmin_submit_new')}][$error]");
if(defined($in{'groupadmin_submit_new'}) and not $error){
  &log($SCRIPT,"- recieve new course submit");
  my $new_course_name = $in{&text('groupadmin_new_group_name')};
  if(defined($new_course_name)){
    &log($SCRIPT,"- Course name is defined.");
    #    #$new_course_name =~ s/^\s+//g;
    #    #$new_course_name =~ s/\s+$//g;
    #    #$new_course_name =~ s/\s+//g;
    #    #$new_course_name =~ s/_+//g;
    #    #$new_course_name =~ s/'+//g;
    $new_course_name = &conversion_login($new_course_name);
    if($new_course_name ne ''){
      #      print "DEBUG: Course name not empty.<br>" if $VERBOSE;
      my $h=0;# hit
      foreach $_ (keys %$course_href){
	chomp();
	if($_ eq $new_course_name){
	  $h = 1;
	}
	#  print "[$h]G '$_' eq '$new_course_name'?<br>" if $VERBOSE;
      }
      if(!$h){
	# print "'$in{'groupadmin_password1'}' eq'in{'groupadmin_password2'}'?<br>" if $VERBOSE;
	if($in{'groupadmin_password1'} eq $in{'groupadmin_password2'}){
	  my $fn=substr($new_course_name,0,2);
	  my $ln=$new_course_name;
	  $ln =~ s/^$fn//;
	  if($ln ne ''){
	    my $cmd="";
	    print "<ul>";
	    my $coursename = &conversion_login($in{&text('groupadmin_new_group_name')});
	    &log($SCRIPT,"- new course name [$coursename]");
	    print "<li>".&text('create_group',$coursename)."</li>";
	    &cipux_task_create_course('cgi',
	        		      $coursename,
				      &conversion_password($in{password}),
				      $size,
				      &cibot_auto_softquota($size));
	    print "<li>".&text('create_private_login',$coursename)."</li>";
	    print "</ul>";
	  }else{
	    &cat_print_html_error(7,&text('_error_groupname_to_short')
				  ."<br>"
				  .&text('groupadmin_once_again'));
	  }
	}else{
	  &cat_print_html_error(8,&text('_error_password_mismatch')
				."<br>"
				.&text('groupadmin_once_again'));
	}
      }else{
	&cat_print_html_error(9,"<b>'$new_course_name'</b>:".&text('_error_password_mismatch'));
      }
    }else{
      &cat_print_html_error(10,&text('_error_empty_groupname'));
    }
  }else{
    &cat_print_html_error(11,&text('_error_not_defined_groupname'));
  }
}else{
  #  print "DEBUG: Recieve NO new group submit<br>" if $VERBOSE;
  #  print "DEBUG: Fehler ='$error'<br>" if $DEBUG;
}

# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+

# if a new group added or a old one deleted we must update the @courses:
if(defined($in{'groupadmin_submit_delete'}) or
   defined($in{'groupadmin_submit_new'})){
   $course_href = &cibot_list_courses_with_gidNumber;
}

print "<h2>".&text('groupadmin')."</h2>";

if($ldap{CipUX}{Cipux_Default_Group_Hard_Quota} == 0){
  print &cat_table_header(3,$tb,&text('groupadmin_known_courses',&text($cipux{Cipux_Course})));
  print &cat_table_row([1,1,1],[$tb,$tb,$tb],[&text('login'),&text('password'),&text('login')]);
  foreach my $g (sort keys %$course_href){
    &log($SCRIPT,"- course [$g]");
    print "<form method=post action='$SCRIPT'>\n";
    print "<input type=hidden name='course' value='$g' >";
    print &cat_table_row([1,0,0],
		       [$tb,'',$cb],
		       [$g,
			&cat_open_passwd_col($SCRIPT,'groupPassword',''),
			&cat_del_col($SCRIPT,
				     'groupadmin_submit_delete',
				     &text('delete'),
				     'hgroup',
				     $g)
 		       ]
			  );
    print "</form>";
  }
}else{
  print &cat_table_row([1,1,1,1,1,1],
		       [$tb,$tb,$tb,$tb,$tb,$tb],
		       [&text('login'),
			&text('disk_usage'),
			&text('hard_quota'),
			&text('password'),
			&text('course')]);
  print &cat_table_header(5,$tb,&text('groupadmin_known_groups'));
  foreach my $g (sort keys %$course_href){
    &log($SCRIPT,"- course [$g]");
    my $fs = $cipux{Cipux_Quota_Filesystem};
    &log($SCRIPT,"- calling: &cibot_get_quota($fs, $$course_href{$g},$quotatype) ");
    my ($bc,$bs,$bh,$bt,$ic,$is,$ih,$it) = &cibot_get_quota($fs,$$course_href{$g},$quotatype);
    &log($SCRIPT,"- calling: &cat_quota_usage_cols($bc,$bs,$bh,$bt,$ic,$is,$ih,$it)");
    my $quota_message = &cat_quota_usage_cols($bc,$bs,$bh,$bt,$ic,$is,$ih,$it);
    my $delete = "";
    $delete = &cat_del_col($SCRIPT,
		           'groupadmin_submit_delete',
		           &text('delete'),
		           'hgroup',
		           $g);
    print "<form method=post action='$SCRIPT'>\n";
    print "<input type=hidden name='course' value='$g' >";
    print &cat_table_row([1,0,0,0,0],
		         [$tb,'',$cb,$cb,$cb],
			 [$g,
			  $quota_message,
			  &cat_quota_set_col($SCRIPT,'gidNumber',$$course_href{$g},$bh),
			  &cat_open_passwd_col($SCRIPT,'groupPassword',''),
			  $delete
			 ]
                        );
    print "</form>";
  }
}

print &cat_table_footer;

print "<h2>".&text('create_new_course_login')."</h2>";

print "<form method=post action='$SCRIPT'>";
print &cat_table_header(2,$tb,
			&text('add_new_object',&text($cipux{Cipux_Course})),
			&text($cipux{Cipux_Course}));
print &cat_table_row(
		     [1,0],
		     [$tb,$cb],
		     [&text('course_login'),
		      "<input type=text maxlength=30 name='".&text('groupadmin_new_group_name')."' size=20>"]);
if($ldap{CipUX}{Cipux_Default_Group_Hard_Quota} > 0){
  print &cat_table_row([1,0],[$tb,$cb],
		       [&text('max_course_quota'),
			"<input type=text maxlength=20 name=size size=10 value='$ldap{CipUX}{Cipux_Default_Group_Hard_Quota}'>"]);
}
print &cat_table_row([1,0],[$tb,$cb],
		     [&text('password').":",
		      "<input type=text maxlength=20 name=password size=10 >"]);
print &cat_table_footer;
print "<input type=submit name=groupadmin_submit_new  value='".&text('groupadmin_submit_new')."'>";
print "</form>";

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);





