#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: index.cgi                                             ||
# ||                                                                      ||
# || (c) 2001 Christian Kuelker                                           ||
# || License: GPL                                                         ||
# +========================================================================+

package index_cgi;


do '../web-lib.pl';
&init_config();

# TODO: check ldap server (REMOTE!!!, not with ps ax)

use CipUX::CiBot;
use CipUX::Cat;

my $BRAND   = "cipworx";
my $PROJECT = "cipux";
my $SCRIPT  = "index.cgi";

&log($SCRIPT,"="x76);
&log($SCRIPT,"LDAP status = [$cibot_ldap_status]");

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

# +=======================================================================+
# || check if the LDAP has still the default password                    ||
# +=======================================================================+
# This is now in /etc/cipux/ldappassword.conf

my @icons = ();
my @text = ();
my @url = ();
my $icons_ref=\@icons;
my $text_ref=\@text;
my $url_ref=\@url;

&cibot_get_ldap_config();

&log($SCRIPT,"useradmin ldap config [$ldap{CAT}{CipUX_Producer}]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);


# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +========================================================================+
# ||  Main                                                                ||
# +========================================================================+

print "<h2>".&text('index_title')."</h2>";

# %HoA
my %index =
  (
   Text  => [ qw(useradmin
		 groupadmin
		 tutoradmin
		 roleadmin
                 transferadmin
		 acladmin
		 examadmin
		 internetadmin
		 mailadmin
		 applicationform
		 apply_applicationform
		 userselfadmin
		 clientadmin
		 roomadmin
		 import
                 cipuxadmin
		 documentation
		 faq
		 hardwareadmin
		 imageadmin
		 imagematrix
		 skeladmin
		 printaccountmanager
		 urlmanager
                 setup
		)],
   Url   => [ qw(useradmin.cgi
		 groupadmin.cgi
		 tutoradmin.cgi
		 roleadmin.cgi
                 transferadmin.cgi
		 acladmin.cgi
		 examadmin.cgi
		 internetadmin.cgi
		 mailadmin.cgi
		 applicationform.cgi
		 apply_applicationform.cgi
		 userselfadmin.cgi
		 clientadmin.cgi
		 roomadmin.cgi
		 import.cgi
                 cipuxadmin.cgi
		 documentation.cgi
	       http://faq.cipux.org
		 hardwareadmin.cgi
		 imageadmin.cgi
		 imagematrix.cgi
		 skeladmin.cgi
		 printaccountmanager.cgi
		 urlmanager.cgi
                 setup.cgi
		)],
   Feature => [ $ldap{CAT}{Cat_Feature_Useradmin},
		$ldap{CAT}{Cat_Feature_Groupadmin},
		$ldap{CAT}{Cat_Feature_Tutoradmin},
		$ldap{CAT}{Cat_Feature_Roleadmin},
		$ldap{CAT}{Cat_Feature_Transferadmin},
		$ldap{CAT}{Cat_Feature_Acladmin},
		$ldap{CAT}{Cat_Feature_Examadmin},
		$ldap{CAT}{Cat_Feature_Internetadmin},
		$ldap{CAT}{Cat_Feature_Mailadmin},
		$ldap{CAT}{Cat_Feature_Applicationform},
		$ldap{CAT}{Cat_Feature_Apply_Applicationform},
		$ldap{CAT}{Cat_Feature_Userselfadmin},
		$ldap{CAT}{Cat_Feature_Clientadmin},
		$ldap{CAT}{Cat_Feature_Roomadmin},
		$ldap{CAT}{Cat_Feature_Import},
                $ldap{CAT}{Cat_Feature_Cipuxadmin},
		$ldap{CAT}{Cat_Feature_Documentation},
		$ldap{CAT}{Cat_Feature_Faq},
		$ldap{CAT}{Cat_Feature_Hardwareadmin},
		$ldap{CAT}{Cat_Feature_Imageadmin},
		$ldap{CAT}{Cat_Feature_Imagematrixadmin},
		$ldap{CAT}{Cat_Feature_Skeladmin},
		$ldap{CAT}{Cat_Feature_Printaccountmanager},
		$ldap{CAT}{Cat_Feature_Urlmanager},
                $ldap{CAT}{Cat_Feature_Setup},
	      ]);

$ldap{CipUX}{CipUX_Institution_Setup_Done} = 0 
  if not defined ($ldap{CipUX}{CipUX_Institution_Setup_Done});

my $i = 0;
foreach my $feature (@{ $index{Feature} }){
  &log($SCRIPT,"- feature [$index{Text}[$i]] [$feature]");
  if($feature){
    &log($SCRIPT,"-> got feature [$index{Text}[$i]]");
    my $acl = $index{Text}[$i];# Cat_Feature_Useradmin, ...
    #ucfirst($acl);
    $acl = "Cat_Acl_".ucfirst($acl);
    &log($SCRIPT," acl [$acl]");
    &log($SCRIPT," acl [$ldap{CAT}{$acl}]");
    &log($SCRIPT," role [$role]");


    if($ldap{CAT}{$acl} =~ m/$role/ or $role eq 'admin'){
      &log($SCRIPT,"-> got acl [$index{Text}[$i]]");
      &log($SCRIPT,"-> Setup [$ldap{CipUX}{CipUX_Institution_Setup_Done}]");
      if($ldap{CipUX}{CipUX_Institution_Setup_Done}){# if setup done add everything
	push(@icons,"images/cipux_".$index{Text}[$i].".png");
	push(@text,&text($index{Text}[$i]));
	push(@url,$index{Url}[$i]);
      }elsif($index{Text}[$i] eq "setup"){# if setup not done add only setup
	push(@icons,"images/cipux_".$index{Text}[$i].".png");
	push(@text,&text($index{Text}[$i]));
	push(@url,$index{Url}[$i]);

      }
    }
  }
  $i++;
}

&icons_table($url_ref,$text_ref,$icons_ref);

#print &cat_explain_message(&text('index_module_hint'));

# +========================================================================+
# ||  footer                                                              ||
# +========================================================================+

#&cat_footer($remote_user,\&footer);

exit(0);
