#!/usr/bin/perl
# +========================================================================+
# || cat Cip-Pool Administration Tool                                     ||
# || webmin Modul                                                         ||
# || Internetadmin                                                        ||
# || (c) 2001 Christian Kuelker                                           ||
# || License: GPL                                                         ||
# +========================================================================+

package internetadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND   = "cipworx";
my $PROJECT = "cipux";
my $SCRIPT  = "internetadmin.cgi";
my $dialog = 0;

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"- ReadParse...");
ReadParse();# webmin

my $course  = $in{'course'}  if defined($in{'course'});
my $disable = $in{'disable'} if defined($in{'disable'});
my $enable  = $in{'enable'}  if defined($in{'enable'});

&log($SCRIPT,"- got course  $course") if defined($course);
&log($SCRIPT,"- got enable  $enable") if defined($enable);
&log($SCRIPT,"- got disable $disable") if defined($disable);

# +========================================================================+
# ||  ENABLE                                                              ||
# +========================================================================+
if(defined($enable)){
  print "<ul><li>".&text('internetadmin_allow_access_for_group',$course)."</li>";
  &cipux_task_enable_internet_for_course('cgi',$course);
  print "</ul>";
}

# +========================================================================+
# ||  DISABLE                                                             ||
# +========================================================================+
if(defined($disable)){
  print "<ul><li>".&text('internetadmin_disallow_access_for_group',$course)."</li>";
  &cipux_task_disable_internet_for_course('cgi',$course);
  print "</ul>";
}

# +========================================================================+
# ||  Main                                                                ||
# +========================================================================+
if(not $dialog){
  print "<h2>".&text('internetadmin')."</h2>";
  &log($SCRIPT,"* print internet access table");
  my $course_href = &cibot_list('C','cipuxInternetStatus');
  my $course_type_href = &cibot_list('C','groupType');

  print &cat_table_header(3,$tb,&text('internetaccess_for_groups'));
  print &cat_table_row([1,1,1],[$tb,$tb,$tb],[&text('group'),&text('type'),&text('access')]);

  foreach my $c (sort keys %$course_href){
    if($$course_type_href{$c} eq "public" ){
      #    print "<tr><form method=post action='$SCRIPT'>";
      my $type = &text('unknown')."$cipux{Cipux_Course}";
      $type = &text($cipux{Cipux_Course}) if $$course_type_href{$c} eq 'public';
      #$type = &text('examination') if $$course_type_href{$c} eq 'school_exam';
      #$type = &text('guest') if $$course_type_href{$c} eq 'guest';
      my $access = "<a href='/cat/$SCRIPT?course=$c&disable=1' title='"
	.&text('press_to_disallow')."'><img src='images/u.png' alt='unknown' border=0></a>";
      $access = "<a href='/cat/$SCRIPT?course=$c&disable=1' title='"
	.&text('press_to_disallow')."'><img src='images/r.png' alt='enable' border=0></a>"
	  if $$course_href{$c} eq 'accept';
      $access = "<a href='/cat/$SCRIPT?course=$c&enable=1' title='"
	.&text('press_to_allow')."'><img src='images/c.png' alt='disable' border=0></a>"
	  if $$course_href{$c} eq 'reject';
      print "<form method=post action='$SCRIPT'>";
      print &cat_table_row([1,0,0],[$tb,'',$cb],[$c,$type,"<center>$access</center>"]);
      print "</form>";
    }
  }
  print &cat_table_footer;
}

# c = red
# w = orange images/c.png <img src='images/w.png'>
# r = green

print &cat_explain_message(&text('internetadmin_explain_01'),$cb);

# +========================================================================+
# ||  Footer                                                              ||
# +========================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);
