#!/usr/bin/perl 
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: printaccountmanager.cgi                               ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || (c) 2005 by Patrick Winnertz                                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package printaccountmanager_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "printaccountmanager.cgi";

&log($SCRIPT,"="x76);

&log($SCRIPT,"- save = [".&text('save')."].");

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}


&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       $remote_user." ($role)",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"- webmin: ReadParse...");
ReadParse();# webmin

my $system = $in{system}    if defined $in{system};# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined $in{$_};
}

my $login=$in{login} if defined $in{login};
my $letter=$in{letter} if defined $in{letter};

# =========================================================================+
# ||                         save_cipuxCredit                             ||
# =========================================================================+
if(defined( $in{save_cipuxCredit_value})){
  &log($SCRIPT,"* save_cipuxCredit");
      if(defined($in{oldvalue})){
      	&log($SCRIPT,"- we got a defined old value. [$in{oldvalue}]");
        if($in{oldvalue} ne ''){
           &log($SCRIPT, "- got cipuxCredit old value [$in{oldvalue}]");
	   my $newvalue=eval("$in{save_cipuxCredit_value} $in{addvalue}");
	   $newvalue = 0 if $newvalue eq '';
	   &log($SCRIPT, "- Value is set to: [$newvalue]");
	   my $cmd ="cipux_set_value -u $login -e cipuxCredit -v '$newvalue'";
	   system($cmd); 
	   my $logfile = "/var/log/cipux/printaccount.log" ; 
	   open (PRINTLOG, ">>$logfile") || die "Can't open $logfile";
	   my $date = `date`;
	   chomp($date);
	   print PRINTLOG "# ".$date." :\n";
	   print PRINTLOG "$cmd\n";
	   close(PRINTLOG);
        }        
      }
}
  
# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+

  print "<h2>".&text('printaccountmanager.cgi')."</h2>";

  
  my $u_credit_href = &cibot_list('U','cipuxCredit');
  my $u_role_href = &cibot_list('U','cipuxRole');
  my $u_firstname_href = &cibot_list('U','cipuxFirstname');
  my $u_lastname_href = &cibot_list('U','cipuxLastname');
  
  my %abc = ();
  foreach (sort keys %$u_role_href) {
  	&log($SCRIPT,"* analyzing user: [$_]");
  	if ($$u_role_href{$_} eq 'account') { #if this a account then... else...
		&log($SCRIPT,"- it's a account"); 
  		my $b = uc(substr($_, 0, 1)); #find out the first letter of the loginname
		&log($SCRIPT,"- the first letter of $_ is: [$b]");
		$abc{$b}=1 ; #collect all known letters of the users
		$letter = $b if not defined($letter) ;
		if (defined($letter))  {
			&log($SCRIPT,"- we got a defined first letter from *.cgi?letter=");
			if ( ($letter ne '' ) and ($letter ne $b)) {
				&log($SCRIPT,"- [$letter] is not empty");
				&log($SCRIPT,"- we delete the login $_ , because it not begin with: [$letter]"); 
				delete($$u_role_href{$_});
			}
		}
	} else {
		&log($SCRIPT,"- this is not an account -> delete it");
		delete($$u_role_href{$_}); #delete all others
	}
	
  }

  print &cat_abc_nav($SCRIPT,\%abc);
  
  #roleadmin table header:
  print &cat_table_header(4,$tb,&text('change_printaccount'));
  print &cat_table_row([1,1,1,1],[$tb,$tb,$tb,$tb], [&text('login'), &text('user'),&text('cipuxCredit')." ".$ldap{CipUX}{CipUX_Currency},&text('add_fixed_credit',$ldap{CipUX}{CipUX_Currency})]);
 
  my $buttons = "<input type=submit name=addvalue value=+100 > 
  <input type=submit name=addvalue value=+200 >
  <input type=submit name=addvalue value=+500 >
  <input type=submit name=addvalue value=+1000 >
  <input type=submit name=addvalue value=+2000 >";
  
  #User ausgeben:
  foreach my $uid (sort keys %$u_role_href) {
  	print "<form method=post action='printaccountmanager.cgi'>";
	if ($$u_credit_href{$uid} eq 'x') {
		$$u_credit_href{$uid}=0;
	}
	print &cat_table_row([1,0,0,0],[$tb,'',$cb,$cb], [ "<a href='/cat/userdata.cgi?login=$uid' >$uid</a>",$$u_firstname_href{$uid}." ".$$u_lastname_href{$uid}, "<input type=text name=save_cipuxCredit_value value='$$u_credit_href{$uid}' > <input type=submit name=save_cipuxCredit value='".&text('save')."'>", $buttons]) ;
	print "<input type=hidden name=login value='$uid'>" ;
	print "<input type=hidden name=oldvalue value='$$u_credit_href{$uid}'>";
	print "<input type=hidden name=letter value='$letter'>"; 
	print "</form>" ;
  }
  
  #roleadmin table footer:
  print &cat_table_footer ."<br>\n";

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);
