#!/usr/bin/perl 
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: roleadmin.cgi                                         ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || (c) 2005 by Patrick Winnertz                                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package roleadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "roleadmin.cgi";

&log($SCRIPT,"="x76);

&log($SCRIPT,"- save = [".&text('save')."].");

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}


&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       $remote_user." ($role)",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"- webmin: ReadParse...");
ReadParse();# webmin

my $system = $in{system}    if defined $in{system};# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined $in{$_};
}

my $login=$in{login} if defined $in{login};
my $letter=$in{letter} if defined $in{letter};

# =========================================================================+
# ||                         save_cipuxRole                               ||
# =========================================================================+
if(defined( $in{save_cipuxRole})){
  &log($SCRIPT,"* save_cipuxRole");
      if(defined($in{cipuxRole})){
        if($in{cipuxRole} ne ''){
           &log($SCRIPT, "- set cipuxRole to value [$in{cipuxRole}]");
	   system("cipux_set_value -c $login -e cipuxRole -v $in{cipuxRole}");
        }        
      }
}
  
# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+

  print "<h2>".&text('roleadmin.cgi')."</h2>";

  
  my $c_role_href = &cibot_list('C','cipuxRole');
  my $u_role_href = &cibot_list('U','cipuxRole');
  my $u_firstname_href = &cibot_list('U','cipuxFirstname');
  my $u_lastname_href = &cibot_list('U','cipuxLastname');
  my %roles = ();
  my @roles = `cipux_task_list_roles` ;
  my $choice = "<select name='cipuxRole' size=1>";
  foreach (@roles) {
  	chomp;
	$roles{$_}=1;
	$choice .= "<option value='$_'>".&text($_)."</option>\n";
  }
  $choice .= "</select>";
  
  my %abc = ();
  #todo: sortiere nach kennung oder username:
  foreach (sort keys %$c_role_href) {
  	&log($SCRIPT,"* analyzing user: [$_]");
  	if (defined($roles{$$c_role_href{$_}})) { #if this a role based account then... else...
		&log($SCRIPT,"- it's a role based account"); 
  		my $b = uc(substr($_, 0, 1)); #find out the first letter of the loginname
		&log($SCRIPT,"- the first letter of $_ is: [$b]");
		$abc{$b}=1 ; #collect all known letters of the users
		$letter = $b if not defined($letter) ;
		if (defined($letter))  {
			&log($SCRIPT,"- we got a defined first letter from *.cgi?letter=");
			if ( ($letter ne '' ) and ($letter ne $b)) {
				&log($SCRIPT,"- [$letter] is not empty");
				&log($SCRIPT,"- we delete the login $_ , because it not begin with: [$letter]"); 
				delete($$c_role_href{$_});
			}
		}
	} else {
		&log($SCRIPT,"- delete not a role based account");
		delete($$c_role_href{$_}); #delete all others
	}
	
  }

  print &cat_abc_nav($SCRIPT,\%abc);
  
  #roleadmin table header:
  print &cat_table_header(5,$tb,&text('change_role'));
  print &cat_table_row([1,1,1,1,1],[$tb,$tb,$tb,$tb,$tb], [&text('login'),&text('user'),&text('old_role'),&text('new_role'),&text('role')]);
  
  
  #User ausgeben:
 
  foreach my $cid (sort keys %$c_role_href) {
  	if (defined($roles{$$c_role_href{$cid}})) {
  		print "<form method=post action='roleadmin.cgi'>";
  		#roleadmin table row: 1.) Login 2.) Role 3.) Neue Role 4.) Save
		if ($$u_role_href{$cid} eq 'account' ) {
			print &cat_table_row([1,0,0,0,0],[$tb,'','','',''], [ "<a href='/cat/userdata.cgi?login=$cid'>$cid</a>",$$u_firstname_href{$cid}." ".$$u_lastname_href{$cid}, &text($$c_role_href{$cid}), $choice ,"<input type=submit name=save_cipuxRole value='".&text('save')."'>"]) ;
		} else {
			print &cat_table_row([1,0,0,0,0],[$tb,'',$cb,''], [$cid, $$u_firstname_href{$cid}." ".$$u_lastname_href{$cid}, &text($$c_role_href{$cid}), "&nbsp;",&text('default')]);
		}
		print "<input type=hidden name=login value='$cid'>" ;
		print "</form>" ;
	}
  }
  
  #roleadmin table footer:
  print &cat_table_footer ."<br>\n";

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);
