#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: setup.cgi                                             ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package setup_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "setup.cgi";

my $question = 1;
my $last_question = 0;


&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

my $system = $in{'system'}    if defined($in{'system'});# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+
print "<h2>".&text('setup')." ($remote_user as $role)</h2>";

# +-----------------------------------------------------------------------+
# || ASK INSTITUTION NAME                                                ||
# +-----------------------------------------------------------------------+
if(not defined($in{question})){
  print " <form method=post action='setup.cgi'>";
  
  print "<h3>Willkommen beim CipUX Setup</h3>";
  #my $iruwc
  my @toppic = qw(CipUX_Institution_Name_Setup_Done CipUX_Institution_Setup_Done CipUX_Image_System_Setup_Done);
  my $toppic = (); 
  foreach (@toppic){
    &log($SCRIPT," ldap [$_] [$ldap{CipUX}{$_}]");	  
    chomp($ldap{CipUX}{$_});
    if($ldap{CipUX}{$_} ne '1'){
      $toppic{$_} = "<img src='images/c.png' alt='ok' border=0>";
    }else{
      $toppic{$_} = "<img src='images/r.png' alt='non' border=0>";
    }
  }	  
  
  print "Die folgenden Bereiche werden abgefragt:<ol>";
  print "<li>Name der Institution     (Frage 1) $toppic{CipUX_Institution_Name_Setup_Done} </li>";
  print "<li>System der Kurs/Klassenstruktur (Fragen 2 - 5) $toppic{CipUX_Institution_Setup_Done}</li>";
  print "<li>CipUX Image System (Fragen 6 - 7) $toppic{CipUX_Image_System_Setup_Done}</li></ol>";
  
 
  print "Wenn das Setup nicht durgef&uuml;hrt werden soll, bitte diesen 
  Link benutzen: ";
  print "Zur&uuml;ck zu <a href='/cat/'>CAT</a>";
  
  if(defined($ldap{CipUX}{CipUX_Institution_Setup_Done})){
  print &cat_explain_message("  
   Das Setup wird erneut durchgef&uuml;rt und die eingestellten
   Werte &uuml;bersschieben.
  ");

  }else{
  print &cat_explain_message("  
  Vielen Dank f&uuml;r die Nutzung von CipUX/CAT!
   Da CAT zum ersten Mal benuzt wird, m&uuml;ssen jetzt einige
   Einstellungen vorgenommen werden.  Diese werden dann in der
  lokalen Datenbank gespeichert.");
  }

  
  &question($in{question});
  my $v = "";
  $v = $ldap{CipUX}{CipUX_Institution_Name} if defined($ldap{CipUX}{CipUX_Institution_Name});
  print " Wie hei&szlig;t ihre Institution?";
  print " <input type=text name=institution value='$v'>";
  print " <input type=hidden name=question value=\"2\" >";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
# +-----------------------------------------------------------------------+
# ||                                                                     ||
# +-----------------------------------------------------------------------+
if($in{question} eq "2"){
  &question($in{question});
  #&question(2);
   my $value = "CipUX_Institution_Name=$in{institution}";
   &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
   $value = "CipUX_Institution_Name_Setup_Done=1";
   &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);


  print " <form method=post action='setup.cgi'>";
  print " Hat diese Institution ($in{institution}) eine Klassenstruktur, &auml;hnlich einer Schule? <br>";
  print " (d.h. &auml;ndern sich die Klassennamen nach jedem Schuljahr? Beispiel: 2a => 2b )";
  print " <br>(Wenn sie sich nicht sicher sind, w&auml;hlen sie <b>nein</b>. Sie k&ouml;nnen diese Frage auch zu einem sp&auml;teren Zeitpunkt mit ja beantorten.)<br>";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=hidden name=question value=\"3\" >";
  print " <input type=submit name=question_answer value=\"".&text('yes')."\"> ";
  print " <input type=submit name=question_answer value=\"".&text('no')."\"> ";
  print " </form>";
}
# +-----------------------------------------------------------------------+
# ||                                                                     ||
# +-----------------------------------------------------------------------+
if($in{question} eq "3" and $in{question_answer} eq &text("yes")){
  my $value = "CipUX_Institution_Structure=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $value="Cat_Feature_Transferadmin=0";
  &cipux_task_change_cipux_config_variable_value('cgi','CAT',$value);
  &question($in{question});
  #&question(3);
  my $v = "0";
  $v = $ldap{CipUX}{CipUX_Institution_Parallel_Courses} if defined($ldap{CipUX}{CipUX_Institution_Parallel_Courses});
  print " <form method=post action='setup.cgi'>";
  print " Wieviele Z&uuml;ge (Parallel-Gruppen/Klassen/Kurse/Seminare/...) gibt es?<br>";
  print &cat_explain_message("
  Beispiel: <br>Wenn es in jedem Jahrgang die Klassen/Seinare/...  a,b und c gibt,
  (also zum Beispiel 1a, 1b, 1c; 2a, 2b ...), dann lautet die Antwort: '<b>3</b>'.");
  print " <input type=hidden name=question value=\"4\" >";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=text name=col_value value='$v'> ";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
# +-----------------------------------------------------------------------+
# ||                                                                     ||
# +-----------------------------------------------------------------------+
if($in{question} eq "3" and $in{question_answer} eq &text("no")){
  # disable transferadmin
  my $value = "CipUX_Institution_Structure=2";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $value="Cat_Feature_Transferadmin=0";
  &cipux_task_change_cipux_config_variable_value('cgi','CAT',$value);
  my $value = "CipUX_Institution_Setup_Done=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $in{question} = 6;
}
# +-----------------------------------------------------------------------+
# || SET CIPUX SCHOOL, ASK YEARS                                         ||
# +-----------------------------------------------------------------------+
if($in{question} eq "4"){
  my $value = "CipUX_Institution_Parallel_Courses=$in{col_value}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  &question($in{question});
  #&question(4);
  my $v = "0";
  $v = $ldap{CipUX}{CipUX_Institution_Course_Levels} if defined($ldap{CipUX}{CipUX_Institution_Course_Levels});
  print " <form method=post action='setup.cgi'>";
  print " Wieviele Jahrg&auml;nge gibt es?<br>";
  print &cat_explain_message("
  Beispiel: <br>
  Wenn es die Klassen/Seminare/Kurse/...  2a, 3a, 4a, 5a und 6a gibt, so 
  lautet die Antwort: '<b>5</b>'.
  ",$cb);
  print "<br>";
  print " <input type=hidden name=question value=\"5\" >";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=hidden name=col_value value=\"$in{col_value}\" >";
  print " <input type=text   name=row_value value='$v'> ";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
# +-----------------------------------------------------------------------+
# || SET YEAR LEVELS, ASK CLASS NAMES                                    ||
# +-----------------------------------------------------------------------+
if($in{question} eq "5"){
# print " <form method=post action='setup.cgi'>";
# print " Sind die Angaben richtig?";
# print " <table border=1>";
# print " <tr $tb> <th $tb colspan=2> Institution: $in{institution}</th></tr>";
# print " <tr><th $cb>Prallel Gruppen: </th><td>$in{col_value}</td></tr>";
# print " <tr><th $cb>Jahrg&auml;nge: </th><td>$in{row_value}</td></tr>";
# print " </table>";
# print " <input type=hidden name=institution value=\"$in{institution}\" >";
# print " <input type=hidden name=question value=\"6\" >";
# print " <input type=hidden name=col_value value=\"$in{col_value}\" >";
# print " <input type=hidden name=row_value value=\"$in{row_value}\" >";
# print " <input type=submit name=question_answer value=\"".&text('yes')."\"> ";
# print " <input type=submit name=question_answer value=\"".&text('no')."\"> ";
# print " </form>";
#
#f($in{question} eq "6" and $in{question_answer} eq &text("yes")){
  my $value = "CipUX_Institution_Course_Levels=$in{row_value}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);

  &question($in{question});
  print " <form method=post action='setup.cgi'>";

    print "
    Bitte die Namen der Klassen, Gruppen, Kurse, Seminare, ... eintragen.
    Die Objekte werden dann erzeugt. Das kann etwas dauern.
    Bitte auch &uuml;pr&uuml;fen ob alles richtig geschrieben ist!<br><br>";
   print &cat_explain_message("Beispiel (2 Jahrg&auml;nge, 2 Z&uuml;ge):
   <table border=1><tr><th>Zug:</th><th>1</th><th>2</th></tr>
          <tr><th>Jahrgang 1:</th><td>1a</td><td>1b</td></tr>
          <tr><th>Jahrgang 2:</th><td>2a</td><td>2b</td></tr>
   </table><br>",$cb);

  print "<br>";
  print &cat_table_header($in{col_value}+1,$tb,"Institution : $in{institution}");
 
  my @col = (1..$in{col_value});
  my @row = (1..$in{row_value});
  my @header = ();
  my @normal = ();
  my @color1 = ();
  my @color2 = ();
  my @coln   = ();
  my @rown   = ();
  my $c = 1;
  push(@normal,1);
  push(@header,1);
  push(@color2,$cb);
  push(@color1,$tb);
  push(@coln,'Zug:');
  foreach(@col){
     push(@header,1);
     push(@normal,0);
     push(@color1,$tb);
     push(@color2,'');
     push(@coln,$c);
     $c++;
  }
  $c=1;
  foreach (@row){
    push(@rown,$c);
    $c++;
  }
  print &cat_table_row(\@header,\@color1,\@coln);

  foreach $row (@rown){
    my @line = ();
    push(@line,"Jahrgang $row:");
    foreach $col (@col){
      my $v = "";
      my $f = "CipUX_Institution_Matrix_".$row."_".$col;
      $v = $ldap{CipUX}{$f} if defined($ldap{CipUX}{$f});
      push(@line,"<input type=text name=Matrix:".$row."_".$col." value='$v'>");
    }
    print &cat_table_row(\@normal,\@color2,\@line);
  }
  print &cat_table_footer ."<br>";
  print " <input type=hidden name=question value=\"class_names\" >";
  print "Voreingestelltes Passwort f&uuml;r obige Klassen/Seminare/Kurse/...:";
  print " <input type=text name=default_password>";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
# +-----------------------------------------------------------------------+
# || SET CLASS NAMES                                                     ||
# +-----------------------------------------------------------------------+
if($in{question} eq 'class_names'){
  print &cat_explain_message("Bitte warten bis die Seite follst&auml;ndig geladen ist.",$cb);
  print "<ul>";
  foreach my $key (sort keys %in){
    # a relevant key?
    if($key =~ /Matrix:/){
      my $line = $key;
      $line =~ s/Matrix://g;
      my ($row, $col) = split(/_/,$line);

      # add this to structure
      print "<li>"."Trage Jahrgang <b>$row</b> und Zug <b>$col</b> in die Struktur ein.</li>";
      my $value = "CipUX_Institution_Matrix_".$row."_".$col."=".$in{$key};
      &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);

      # create a group
      print "<li>"."Erstelle Objekt <b>$in{$key}</b></li>";
      &cipux_task_create_course('cgi',$in{$key},$in{default_password});
    }
  }
  print "</ul>";

  # set Setup_Ok in ldap server

  # print ok message
  my $value = "CipUX_Institution_Setup_Done=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  print &cat_explain_message("Das Setup wurde durchgef&uuml;hrt.",$cb);

  $in{question} = 6;

}
# +-----------------------------------------------------------------------+
# || ASK IMAGE SYSTEM                                                    ||
# +-----------------------------------------------------------------------+
if($in{question} eq "6"){
  print "<h3> CipUX Image Verfahren </h3>";
  print "Das CipUX Image Verfahren kann Betriebsystem-Abbilder vom Hauptserver 
          auf Fat-Clients (Computer mit Festplatte) mittels einer RemoteBoot
	  Netzwerkarte (PXE, Etherboot) anhand voreingestellter Werte durch CAT
	  &uuml;bers Netzwerk verteilen. Die Betriebssystem-Abbilder m&uuml;ssen
	  selbst erstellt werden. Dabei sind sowohl Opensource Systeme als auch
          andere m&ouml;glich.<br><br>";
  print "Die Vorteile sind:";
  print "<ul>";
  
  print "<li>Der Verwaltungsaufand f&uuml;r eine Vielzahl (> 14) Computer vereinfacht sich.</li>";
  print "<li>Die &Auml;nderung an einem Computer kann in kurzer Zeit auf alle anderen &uuml;bertragen werden.</li>";
  print "<li>Das Neuinstallieren eines Computers kann automatisch erfolgen.</li>";
  print "<li>Auf Wunsch k&ouml;nnen in einem Raum verschiedene Systeme voreingestellt werden.</li>";
  print "<li>Multibootsysteme werden unterst&uuml;tzt.</li>";
  print "<li>Durch den Hardware Abstraction Layer braucht man keine absolut homogene Hardware.</li>";
  print "<li>Die Installationsintervalle k&ouml;nnen festgelegt werden.</li>";
  print "<li>Verteilung von Systemen erfolgt auf Raumbasis.</li>";
#  print "<li></li>";
#  print "<li></li>";
  print "</ul>";
  print "Die Nachteile sind:";
  print "<ul>";
  print "<li>Das Verfahren wurde mit Debian-Edu noch nicht oft getestet.</li>";
  print "<li>Es k&ouml;nnte nicht zu den WLUS Netgroups passen.</li>";
#  print "<li>Es k&ouml;nnte noch nicht mit Thin Clients zusammenarbeiten.</li>";
  print "<li>Es spart nur Arbeit wenn man relativ homogene Hardware hat.</li>";
  print "<li>Es lohnt sich erst so ca. ab einem Computerraum, d.h. ab ca 14 Computern</li>";
 
  print "</ul>";

  &question($in{question});
  print " <form method=post action='setup.cgi'>";
  print " M&ouml;chten sie das CipUX Image Verfahren einsetzen? <br>";
  print " (Wenn sie sich nicht sicher sind, w&auml;hlen sie <b>nein</b>. Sie k&ouml;nnen diese Frage auch zu einem sp&auml;teren Zeitpunkt mit ja beantorten.)<br>";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=hidden name=question value=\"7\" >";
  print " <input type=submit name=question_answer value=\"".&text('yes')."\"> ";
  print " <input type=submit name=question_answer value=\"".&text('no')."\"> ";
  print " </form>";
} 
# +-----------------------------------------------------------------------+
# || SET IMAGE SYSTEM, ASK ROOMS                                         ||
# +-----------------------------------------------------------------------+
if($in{question} eq "7"){ 
  if($in{question_answer} eq &text("yes")){# yes
    my $value = "CipUX_Image_System=1";
    &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Imageadmin=1');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Hardwareadmin=1');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Imagematrix=1');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Clientadmin=1');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Roomadmin=1');

     print("Die Anzahl verschiedener Hardware mal die Anzahl verschiedener
           Software Standards (Software Gruppen) ergibt die Anzahl m&ouml;glicher
           Images.<br><br>");

     print &cat_explain_message("Beispiel 1 (homogener Computer Raum): Wenn sie ein Raum haben und 
            eine Sorte von Hardware (indentische Hardware) und sie m&ouml;chten nur ein Betriebssystem dort
            einsetzen brauchen sie auch nur ein Image zu erstellen.",$cb);
 
     print &cat_explain_message("Beispiel 2 (homogener Dualboot Raum): Wenn sie einen Raum haben und
            ein Hardware Standard, aber 2 Betriebsysteme einsetzen wollen, m&uuml;ssen
            sie f&uuml;r jedes Betriebssystem 1 Image, also insgesamt 2 Images erstellen.",$cb);

     print &cat_explain_message("Beispiel 3 (heterogene Landschaft) Sie haben Computer 
             Typ A und Computer 
            Typ B und wollen
            2 verschiedene Linuxe und ein Propriet&auml;res Betriebssystem einsetzen,
            dann m&uuml;ssen sie - wenn sie die Hardware in einem Raum mischen -
            3x2 = 6 Images herstellen. Wenn sie Computer Linuxe nur auf Typ
            A und das andere System nur auf Typ B installieren wollen oder wenn sie
            die Computer auf unterschiedliche R&auml;me aufteilen oder anderweitig 
            entflechten, brauchen sie nur 1x2 + 1x1 = 3 Images herstellen. ",$cb);

    print(" <br><br>Um auch zuk&uuml;nftigen 
            Software Gruppen oder noch ein oder zwei Hardware Standards  mehr 
            unterst&uuml;tzen zu k&ouml;nnen, sollten ein paar Hardware Standards
            und Software Gruppen mehr als sie ben&ouml;tigen angeben. Zum Beispiel
            werden 20 Hardware Standards und 20 Software Gruppen empfohlen. Damit 
            k&ouml;nnen sie maximal 400 Images herstellen. 
            Nat&uuml;rlich k&ouml;nnen sie die
            Hardware Standards und auch die Software Gruppen wiederverwenden. Wenn
            sie es wollen k&ouml;nnen sie sich somit Jahrzehnte mit der Imageherstellung beschaeftigen.<br><br>");



    print "<font color='$warning'>WARNUNG: Es wird empfohlen diese Fragen nur 
    <b>einmal</b> beim Setup zu beantworten und <b>nicht</b> mehr zu &auml;ndern!
    Wenn sie dieses System schon nutzen und diese Werte ab&auml;ndern sollten, <b>werden</b> Daten 
    verloren gehen! Die Zuordnung
    der LDAP Daten zu denen im Filesystem gespeicherten Images wird hierdurch aufgehoben.
    </font>";    


  &question($in{question});
    print "Anzahl der verscheidenen Software Standards?<br> (Image Slots, Anzahl 
            verschiedener Betriebsysteme, Image Gruppen, ...) Hier 
            hier empfiehlt sich ein Wert von nicht mehr als 20: <br><br>";
    #
    #  CipUX_Hal_Image_Slot_Max
    #
    print " <form method=post action='setup.cgi'>";
    my $v = "";
    $v = $ldap{CipUX}{CipUX_Hal_Image_Slot_Max} 
         if defined($ldap{CipUX}{CipUX_Hal_Image_Slot_Max});
    if($v eq ""){	 
     print " <input type=text name=CipUX_Hal_Image_Slot_Max  value='$v'>";
    }else{
      print " <b>$v</b> ";
      print " <input type=hidden name=CipUX_Hal_Image_Slot_Max   value='$v'>";
    }

     print " Standards/ Gruppen <br><br>Anzahl der unterst&uuml;tzten Hardware Standards?<br> 
            (F&uuml;r eine mittelgrosse Organisatzion empfiehlt es sich nicht mehr 
            als 20 verschiedene Standards zu unterst&uuml;tzen): <br><br>";
    #
    # CipUX_Hal_Hardware_Type_Max (CipUX_Hal_Hardware_Type_Nics) 
    #
    $v = "";
    $v = $ldap{CipUX}{CipUX_Hal_Hardware_Type_Max} 
         if defined($ldap{CipUX}{CipUX_Hal_Hardware_Type_Max});
    if($v eq ""){	 
      print " <input type=text name=CipUX_Hal_Hardware_Type_Max value='$v'>";
    }else{
      print " <b>$v</b> ";
      print " <input type=hidden name=CipUX_Hal_Hardware_Type_Max value='$v'>";
    }
    print " Standards <br><br>";

    print "Voreingstellter Image Typ [ tgz oder cci ]? ";
    print &cat_explain_message("Wenn sie ein sehr einfaches Betriebssystem nehmen, ist tgz die richtige Wahl, f&uuml;r alle anderen (auch Linux) empfiehlt sich cci (auf dd basiered).)",$cb);
    $v = "";
    $v = $ldap{CipUX}{CipUX_Hal_Default_Image_Type}; 
    print "<select name='CipUX_Hal_Default_Image_Type' size=1>";
    if($v eq "cci" or $v eq ""){
      print "<option selected value='cci'>cci</option>";
      print "<option value='tgz'>tgz</option>";
    }else{	    
      print "<option value='cci'>cci</option>";
      print "<option selected value='tgz'>tgz</option>";
    }
    print "</select>";
    print " [tgz oder cci]";
   
    
    print " <input type=hidden name=question value=\"8\" >";
    print "<br><br> <input type=submit name=question_answer value=\"".&text('save')."\">";
    print " </form>";
    

  }else{
    my $value = "CipUX_Image_System=0";
    &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Imageadmin=0');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Hardwareadmin=0');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Imagematrix=0');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Clientadmin=0');
    &cipux_task_change_cipux_config_variable_value('cgi','CAT','Cat_Feature_Roomadmin=0');
    $last_question = 1;
 }
  
}  
# +-----------------------------------------------------------------------+
# || SET HAL                                                             ||
# +-----------------------------------------------------------------------+
if($in{question} eq "8"){
  my $value = "CipUX_Hal_Hardware_Type_Max=$in{CipUX_Hal_Hardware_Type_Max}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $value = "CipUX_Hal_Image_Slot_Max=$in{CipUX_Hal_Image_Slot_Max}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $value = "CipUX_Hal_Default_Image_Type=$in{CipUX_Hal_Default_Image_Type}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);

  if($ldap{CipUX}{CipUX_Image_System_Setup_Done}){
    print "Setup wurde bereits durchgef&uuml;hrt.";

  }else{	    
    my $hwt_max = "000".$in{CipUX_Hal_Hardware_Type_Max};
    $hwt_max =~ s/\d*(\d\d\d)$/$1/g;
    &log($SCRIPT,"* hwt_max [$hwt_max]");
    my @hwt = ('001' .. $hwt_max);
    my $is_max = "000".$in{CipUX_Hal_Image_Slot_Max};
    $is_max =~ s/\d*(\d\d\d)$/$1/g;
    &log($SCRIPT,"* is_max  [$is_max]");
    my @is = ('001' .. $is_max );

    my $image="000001";
    print "<ul>";
    foreach my $hwt (@hwt){
      &log($SCRIPT,"* add hwt [$hwt]");
      print "<li> f&uuml;ge Hardware Type hinzu: [$hwt]</li>";
      # cipux_task_create_hardware_type CN hardware_type_name hardware_type_protect hardware_type_nic
      `cipux_task_create_hardware_type $hwt 'hardware standard $hwt' FALSE all`;
      print "<ul>";
      foreach my $is (@is){
        &log($SCRIPT,"* add is  [$is]");
        print "<li> f&uuml;ge Software Gruppe hinzu: [$is]</li>";
        # cipux_task_create_image_slot CN image_slot_name image_slot_protect image_slot_enabled
        `cipux_task_create_image_slot $is 'software group $is' FALSE TRUE`;
        &log($SCRIPT,"* add image [$image]");
        print "<li> f&uuml;ge Image Daten hinzu: [$image]</li>";
        #cipux_task_create_image CN image_name image_type image_protect image_enabled image_size checksum hardware_type_number image_slot_number
	`cipux_task_create_image $image 'CipUX Image $image' $in{CipUX_Hal_Default_Image_Type} FALSE TRUE 0 0 $hwt $is `;
	$image++;
      }
    print "</ul>";
    }
    print "</ul>";
  }  
  $value = "CipUX_Image_System_Setup_Done=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);

    
  print "Das CipUX Image system ist nun vorkonfiguriert. Wenn sie es nutzen
  wollen lesen sie bitte das Handbuch und erstellen sie R&auml;me und 
  registrieren sie Computer-Clients.<br>";
    
  $last_question = 1;
}


# +-----------------------------------------------------------------------+
# || LAST                                                                ||
# +-----------------------------------------------------------------------+
if($last_question){

  print "Setup abgeschlossen.<br><br>";
  print "Zur&uuml;ck zu <a href='/cat/'>CAT</a>";

}	


# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
if($last_question){
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
}else{
  #&cat_footer($remote_user,\&footer,'');
}

exit(0);

sub question{
   my $question = shift;
   $question = 1 if $question eq "";
  print "<h1> Frage $question:</h1>";

}	

