#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: transferadmin.cgi                                     ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package transferadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "transferadmin.cgi";

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

#my $system = $in{'system'} if defined($in{'system'});# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

my %roles = ();
my @roles = `cipux_task_list_roles`;
foreach(@roles){chomp;$roles{$_}=1}

$in{question} = 1 if not defined($in{question});




# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+
print "<h2> Versetungen ($remote_user as $role)</h2>";
if($in{question} eq "1"){

  print "<h3>Erkl&auml;rung</h3>";

  print "
  Dieses Modul wird nur von Institutionen 
  ben&ouml;tigt, deren Klassen/Kurs/Seminarnamen sich j&auml;hrlich systematisch &auml;ndern. 
  Oder aus der Sicht der Institution: Die Mitglieder der
  Institution durchlaufen definierte Ebenen der Einrichtung. <br><br>";
  print &cat_explain_message("
  Beispiel:<br> Man kann sich
  das sehr einfach am Beispiel einer Grundschule deutlich machen. Alle 
  Sch&uuml;ler werden in vier Z&uuml;gen a, b, c und d eingeschult. Deren 
  Klassenname leitet sich somit aus dem ersten Level ab: 1a, 1b, 1c und 1d. Die Schule
  hat insgesamt 4 Jahrg&auml;nge.
  Dieses
  Modul wird nun am Ende des Schuljahrs aufgerufen. Ausgehend vom Jahrgang 4 mit
  den Klassen 4d, 4c, 4b und 4a bis zur 1d, 1c, 1b und 1a werden die Sch&uuml;ler
  klassenweise versetzt, abgehen, sitzenbleiben oder den Zug wechseln.
",$cb);
  print "<br>";

  print &cat_explain_message("
  Hinweis:<br> Wenn <b>abgehen</b> gew&auml;lt wird, wird die Kennung gel&ouml;scht.
  Falls die Kennung nicht sofort gel&ouml;scht werden soll, wird empfohlen die
  Kennung einer neuen Gruppe zuzuordnen. Man k&ouml;nnte sie z.B. 'abgang' nennen.
",$cb);
 print "<br>";

  print "<h3>Z&uuml;ge und Jahrg&auml;nge</h3>";
  print &cat_table_header(2,$tb,"Instituition: $ldap{CipUX}{CipUX_Institution_Name}");
  print &cat_table_row([1,1],[$cb,""],
		       ["transferadmin_cipux_institution_course_levels",
			,$ldap{CipUX}{CipUX_Institution_Course_Levels}]);
  print &cat_table_row([1,1],[$cb,""],
		       ["transferadmin_cipux_institution_parallel_courses",
			,$ldap{CipUX}{CipUX_Institution_Parallel_Courses}]);
 print &cat_table_footer ."<br>";
  
  print "<h3>Namen der Klassen/Kurse/Seminare/ ...</h3>";
  

    print " <form method=post action='transferadmin.cgi'>";
  print &cat_table_header($ldap{CipUX}{CipUX_Institution_Parallel_Courses}+1,$tb,"Institution: $ldap{CipUX}{CipUX_Institution_Name}");
  
  
  my @col = (1..$ldap{CipUX}{CipUX_Institution_Parallel_Courses});
  my @row = (1..$ldap{CipUX}{CipUX_Institution_Course_Levels});
  my @header = ();
  my @normal = ();
  my @color1 = ();
  my @color2 = ();
  my @coln   = ();
  my @rown   = ();
  my @courses = ();
  my @last = ();
  my $c = 1;
  push(@normal,1);
  push(@header,1);
  push(@color2,$cb);
  push(@color1,$tb);
  push(@coln,'Zug:');
  foreach(@col){
    push(@header,1);
    push(@normal,0);
    push(@color1,$tb);
    push(@color2,'');
     push(@coln,$c);
    $c++;
  }
  $c=1;
  foreach (@row){
    push(@rown,$c);
    $c++;
  }
  print &cat_table_row(\@header,\@color1,\@coln);
  
  foreach $row (@rown){
    my @line = ();
    push(@line,"Jahrgang $row:");
    foreach $col (@col){
      my $v = "";
      my $f = "CipUX_Institution_Matrix_".$row."_".$col;
      $v = $ldap{CipUX}{$f} if defined($ldap{CipUX}{$f});
      #push(@line,"<input type=text name=Matrix:".$row."_".$col." value='$v'>");
      push(@line,"$v <input type=hidden name=Matrix:".$row."_".$col." value='$v'>");
      push(@courses,$v);

      # calculate the last level, because there will no transfer for that

      if($row eq $ldap{CipUX}{CipUX_Institution_Course_Levels}){
	push(@last,1);
      }else{
	push(@last,0);
      }
      
    }
    print &cat_table_row(\@normal,\@color2,\@line);
  }
  print &cat_table_footer ."<br>";
  my $courses = "'".join("' '",reverse(@courses))."'";
  my $last = join(" ",reverse(@last));
  &log($SCRIPT,"- courses [$courses]");
  &log($SCRIPT,"- last    [$last]");
  print " <input type=hidden name=question value=\"2\" >\n";
  print ' <input type=hidden name=courses value="'.$courses.'"'." >\n";
  print ' <input type=hidden name=last value="'.$last.'"'." >\n";
  print " <input type=submit name=question_answer value=\"".&text('ok')."\">\n";
  print " </form>";
}
#
# do the action
#
if($in{question} eq "3" ){

  # first calculate the transfer martix
  %transfer_matrix_row = {};
  %transfer_matrix_col = {};
  %matrix = {};
  foreach my $var (keys %{$ldap{CipUX}}){
    &log($SCRIPT,"- var [$var]");
    if($var =~ /CipUX_Institution_Matrix_/){
      $value = $ldap{CipUX}{$var};
      &log($SCRIPT,"- value [$value]");
      $v = $var;
      $v =~ s/CipUX_Institution_Matrix_//; # rest: 1_2
      my ($r,$c)=split(/_/,$v);
      &log($SCRIPT,"- row [$r] col [$c]");
      $transfer_matrix_row{$value}=$r+1; # the next year is the transfer year
      $transfer_matrix_col{$value}=$c;   # the prallel group remain the same
      $matrix{$r}{$c}=$value;
    }
  }

  # then ...
  $in{uid} =~ s/\s+//g;
  $in{uid} =~ s/^\s+//; # delete leading space
  $in{uid} =~ s/\s+$//; # delete trailing space
  $in{action} =~ s/\s+//g;
  $in{action} =~ s/^\s+//; # delete leading space
  $in{action} =~ s/\s+$//; # delete trailing space
  &log($SCRIPT,"- uid    [$in{uid}]");
  &log($SCRIPT,"- action [$in{action}]");
  my @uid = split(/\0/,$in{uid});
  my @action = split(/\0/,$in{action});
  my $z=0;
  print "<ul>";
  foreach my $uid (@uid){
    &log($SCRIPT,"- uid [$uid]");
    if(defined($uid)){
    if($uid ne ""){
      if($action[$z] eq 'repeat'){
	print "<li>Die Kennung <b>$uid</b> bleibt in der Gruppe.</li>";
      }elsif($action[$z] eq 'leave'){
	print "<li>Die Kennung <b>$uid</b> wird gel&ouml;scht.</li>";
        &cipux_task_delete_user('$cgi',$uid);
	print "<li>Die Kennung <b>$uid</b> wird aus der Gruppe <b>$in{old_course}</b> entfernt.</li>";
        &cipux_task_remove_user_from_course('cgi',$in{old_course},$uid);
      }elsif($action[$z] eq 'transfered'){
	my $col = $transfer_matrix_col{$in{old_course}};
        my $row = $transfer_matrix_row{$in{old_course}};
        my $cid = $matrix{$row}{$col};
	print "<li>Die Kennung <b>$uid</b> steigt eine Gruppe auf: von <b>$in{old_course}</b>  nach <b>$cid</b>. (Das ist Jahrgang <b>$row</b>, Zug <b>$col</b>)</li>";
	print "<li>Die Kennung <b>$uid</b> wird aus der Gruppe <b>$in{old_course}</b> entfernt.</li>";
        &cipux_task_remove_user_from_course('cgi',$in{old_course},$uid);
	print "<li>Die Kennung <b>$uid</b> wird der  Gruppe <b>$cid</b> zugeordnet.</li>";
	&cipux_task_add_user_to_course('cgi',$cid,$uid);
        
      }else{
	# the order is important
	print "<li>Die Kennung <b>$uid</b> wird aus der Gruppe <b>$in{old_course}</b> entfernt.</li>";
        &cipux_task_remove_user_from_course('cgi',$in{old_course},$uid);
	print "<li>Die Kennung <b>$uid</b> wird der  Gruppe <b>$action[$z]</b> zugeordnet.</li>";
	&cipux_task_add_user_to_course('cgi',$action[$z],$uid);
      }
    }
  }
    $z++;
  }
  print "</ul>";

  $in{question}=2;
}

#
# a new member course matrix 
#
if($in{question} eq "2" and $in{courses} ne "''"){

  my $cipuxFirstname_href = &cibot_list('U','cipuxFirstname');
  my $cipuxLastname_href  = &cibot_list('U','cipuxLastname');
  
  my @transfer_last = split(/ /,$in{last});
  my $courses = $in{courses};
  $courses=~s/^'+//g;
  $courses=~s/'+$//g;# del the first ' and the last '
  my @transfer_courses = split(/' '/,$courses);
  my $c = shift(@transfer_courses);
  my $l = shift(@transfer_last);
  $courses = "'".join("' '",@transfer_courses)."'";
  my $last = join(" ",@transfer_last);
  &log($SCRIPT,"- courses [$courses] + [$c]");
  &log($SCRIPT,"- last    [$last] + [$l]");
  my @choice = qw(transfered leave repeat);  
  foreach(@choice){$choice{$_}=1}
  my @courses = sort(&cipux_task_list_courses('cgi'));
  push(@choice,@courses);

  print  "<form method=post action='transferadmin.cgi'>";
  print &cat_table_header(2,$tb,"Verzetungen: $c ");
  my @member = &cipux_task_list_user_members_of_course('cgi',$c);
  print &cat_table_row([1,1],[$tb,$tb],[&text('login'),&text('action')]);
  my $choice  = " <select name='action' size=1>";
  if($l){# if last level
    &log($SCRIPT,"- last level");
    foreach (@choice){
      if($_ ne "transfered"){
	if($_ eq "leave"){
	  $choice .= "<option selected value=' $_ '>".&text($_)."</option>\n";
	}elsif(defined $seen{$_}){
	  $choice .= "<option value=' $_ '>".&text($_)."</option>\n";
	}else{
	  $choice .= "<option value=' $_ '>$_</option>\n";
	}
      }
    }
  }else{
    &log($SCRIPT,"- not last level");
    foreach (@choice){
      if($_ eq "transfered"){
	$choice .= "<option selected value=' $_ '>".&text($_)."</option>\n";
      }elsif(defined $seen{$_}){
	$choice .= "<option value=' $_ '>".&text($_)."</option>\n";
      }else{
	$choice .= "<option value=' $_ '>$_</option>\n";
      }
    }
  }
  $choice  .= "</select>";
  foreach my $uid (@member){

    $uid .= " ($$cipuxLastname_href{$uid}, $$cipuxFirstname_href{$uid}) ";
    $uid .= "<input type=hidden name=uid value=' $uid '>";
    print &cat_table_row([1,0],
			 ['',$cb],
			 [$uid,$choice]
			);
  }
  print &cat_table_footer ."<br>";
  print "<input type=hidden name=question value=3>\n";
  print "<input type=hidden name=old_course value=\"$c\" >\n";
  print "<input type=hidden name=courses value=\"$courses\">\n";
  print "<input type=hidden name=last value=\"$last\">\n";
  print "<input type=submit name=next_transfer value=\"".&text('save')."\"> \n";
  
  $choice  .= "</form>\n";
}
#
# The last course was processed
#
if($in{question} eq "2" and $in{courses} eq "''"){
  print &cat_explain_message("Alle Aktionen wurden durchgef&uuml;hrt.",$cb);
}




# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);

